-- 初始化数据脚本

-- 表模型信息
CREATE TABLE CORE_TABLES
(
  RWID           VARCHAR(32) NOT NULL,
  MX_MINGC           NVARCHAR(32) NOT NULL,
  MX_BIANH           VARCHAR(32) NOT NULL,
  MX_ZHUJZD         VARCHAR(32),
  MX_BIAOLX          INT NOT NULL,
  MX_SHIFCJ          INT NOT NULL,  
  SYS_SORT             INT,
  SYS_PARENTID         VARCHAR(32),
  SYS_PARENTS          VARCHAR(255),
  SYS_ISLEAF           INT,
  SYS_CREATOR          VARCHAR(32) NOT NULL,
  SYS_CREATETIME       DATETIME NOT NULL,
  SYS_MODIFYBY         VARCHAR(32),
  SYS_MODIFYTIME       DATETIME,
  SYS_STATUS           INT
);
ALTER TABLE CORE_TABLES
  ADD CONSTRAINT PK_CORE_TABLES PRIMARY KEY (RWID);

-- 表的字段表
CREATE TABLE CORE_TABLES_COLUMNS
(
  RWID         VARCHAR(32) NOT NULL,
  MXZD_TABLEID  VARCHAR(32) NOT NULL,
  MXZD_BIANH         VARCHAR(32) NOT NULL,
  MXZD_MINGC         NVARCHAR(32) NOT NULL,
  MXZD_YINGWM        VARCHAR(32) ,
  MXZD_ZIDLX       VARCHAR(32) NOT NULL,
  MXZD_ZIDCD         INT ,
  MXZD_MIAOS         VARCHAR(32),
  MXZD_XIAOSJD         INT,
  MXZD_YUNXWK         INT DEFAULT 1 NOT NULL ,
  MXZD_SHIFWY         INT DEFAULT 0 NOT NULL ,
  MXZD_SHIFCJ         INT DEFAULT 0 NOT NULL ,  
  MXZD_MORZ        NVARCHAR(100),  
  SYS_SORT             INT,
  SYS_CREATOR          VARCHAR(32) NOT NULL,
  SYS_CREATETIME       DATETIME NOT NULL,
  SYS_MODIFYBY         VARCHAR(32),
  SYS_MODIFYTIME       DATETIME,
  SYS_STATUS           INT
);
ALTER TABLE CORE_TABLES_COLUMNS ADD CONSTRAINT PK_CORE_TABLES_COLUMNS PRIMARY KEY (RWID);
CREATE UNIQUE INDEX IDX_CORE_TABLES_COLUMNS ON CORE_TABLES_COLUMNS (MXZD_TABLEID, MXZD_BIANH);  

-- 表的索引表
CREATE TABLE CORE_TABLES_INDEXS
(
  RWID     VARCHAR(32) NOT NULL,
  MXSY_TABLEID  VARCHAR(32) NOT NULL,
  MXSY_BIANH      VARCHAR(32) NOT NULL,
  MXSY_ZIDLB   VARCHAR(255) NOT NULL,
  MXSY_SHIFWY   INT NOT NULL,
  MXSY_SHIFCJ   INT DEFAULT 0 NOT NULL ,  
  SYS_SORT             INT,
  SYS_CREATOR          VARCHAR(32) NOT NULL,
  SYS_CREATETIME       DATETIME NOT NULL,
  SYS_MODIFYBY         VARCHAR(32),
  SYS_MODIFYTIME       DATETIME,
  SYS_STATUS           INT    
);
ALTER TABLE CORE_TABLES_INDEXS
  ADD CONSTRAINT PK_CORE_TABLES_INDEXS PRIMARY KEY (RWID);


-- 表的关系表
CREATE TABLE CORE_TABLES_LINKS
(
  RWID     VARCHAR(32) NOT NULL,
  MXYS_TABLEID  VARCHAR(32) NOT NULL,
  MXYS_BIANH     VARCHAR(32) NOT NULL,
  MXYS_XUYGLZD  VARCHAR(32) NOT NULL,
  MXYS_GUANLB    VARCHAR(32) NOT NULL,
  MXYS_GUANLBZD   VARCHAR(32) NOT NULL,
  MXYS_GUANLBLX   INT NOT NULL,
  MXYS_SHIFCJ   INT DEFAULT 0 NOT NULL ,  
  SYS_SORT             INT,
  SYS_CREATOR          VARCHAR(32) NOT NULL,
  SYS_CREATETIME       DATETIME NOT NULL,
  SYS_MODIFYBY         VARCHAR(32),
  SYS_MODIFYTIME       DATETIME,
  SYS_STATUS           INT  
);
 
ALTER TABLE CORE_TABLES_LINKS
  ADD CONSTRAINT PK_CORE_TABLES_LINKS PRIMARY KEY (RWID);

ALTER TABLE CORE_TABLES_COLUMNS
  ADD CONSTRAINT CORE_TABLES_COLUMNS_FK_1 FOREIGN KEY (MXZD_TABLEID)
  REFERENCES CORE_TABLES (RWID) ON DELETE CASCADE;
  
ALTER TABLE CORE_TABLES_INDEXS
  ADD CONSTRAINT CORE_TABLES_INDEXS_FK_1 FOREIGN KEY (MXSY_TABLEID)
  REFERENCES CORE_TABLES (RWID) ON DELETE CASCADE;
  
ALTER TABLE CORE_TABLES_LINKS
  ADD CONSTRAINT CORE_TABLES_LINKS_FK_1 FOREIGN KEY (MXYS_TABLEID)
  REFERENCES CORE_TABLES (RWID) ON DELETE CASCADE;

  
  
-- 数据字典主表
CREATE TABLE CORE_DICTIONARY
(
  RWID    VARCHAR(32) NOT NULL,
  ZDMX_BIANH    VARCHAR(32) NOT NULL,
  ZDMX_MINGC    NVARCHAR(32) NOT NULL,
  ZDMX_LEIX    VARCHAR(32) NOT NULL,
  ZDMX_GUANLBM	 VARCHAR(32),
  ZDMX_SUOSXT  VARCHAR(32) NOT NULL,
  SYS_SORT         INT,
  SYS_CREATOR      VARCHAR(32) NOT NULL,
  SYS_CREATETIME   DATETIME NOT NULL,
  SYS_MODIFYBY     VARCHAR(32),
  SYS_MODIFYTIME   DATETIME,
  SYS_STATUS       INT
);  
ALTER TABLE CORE_DICTIONARY
  ADD CONSTRAINT PK_CORE_DICTIONARY PRIMARY KEY (RWID);
  
CREATE UNIQUE INDEX IDX_CORE_DICTIONARY ON CORE_DICTIONARY (ZDMX_BIANH);

-- 数据字典明细表
CREATE TABLE CORE_DICTIONARYMX
(
  RWID  VARCHAR(32) NOT NULL,
  ZDZ_DICTIONARYID    VARCHAR(32) NOT NULL,
  ZDZ_MINGC    VARCHAR(32) NOT NULL,
  ZDZ_BIANH  VARCHAR(32),  
  ZDZ_YANGS    NVARCHAR(255),
  ZDZ_SHIFQY    INT,
  ZDZ_ZIDZ   VARCHAR(2000),
  SYS_SORT         INT,
  SYS_CREATOR      VARCHAR(32) NOT NULL,
  SYS_CREATETIME   DATETIME NOT NULL,
  SYS_MODIFYBY     VARCHAR(32),
  SYS_MODIFYTIME   DATETIME,
  SYS_PARENTID     VARCHAR(32),
  SYS_PARENTS      VARCHAR(1000),
  SYS_STATUS       INT  
);
ALTER TABLE CORE_DICTIONARYMX
  ADD CONSTRAINT PK_CORE_DICTIONARYMX PRIMARY KEY (RWID);

-- -- 功能管理
-- CREATE TABLE CORE_FUNCTIONS
-- (
--   FUNCTIONS_ID  VARCHAR(32) NOT NULL,
--   FUNCTIONS_RWID  VARCHAR(32) NOT NULL,
--   FUNCTIONS_BH    VARCHAR(32) NOT NULL,
--   FUNCTIONS_MC    VARCHAR(32) NOT NULL,
--   FUNCTIONS_YWMC  VARCHAR(32),
--   FUNCTIONS_URL  VARCHAR(255),

--   SYS_SORT         INT,
--   SYS_CREATOR      VARCHAR(32) NOT NULL,
--   SYS_CREATETIME   DATETIME NOT NULL,
--   SYS_MODIFYBY     VARCHAR(32),
--   SYS_MODIFYTIME   DATETIME,
--   SYS_STATUS       INT,
--   SYS_PARENTID     VARCHAR(32),
-- 	SYS_PARENTS      VARCHAR(1000),
-- 	SYS_ISLEAF       INT
-- );
-- ALTER TABLE CORE_FUNCTIONS
--   ADD CONSTRAINT PK_CORE_FUNCTIONS PRIMARY KEY (FUNCTIONS_ID);

-- 文件资源表
CREATE TABLE CORE_FILESRES
(
  RWID    VARCHAR(32) NOT NULL,
  WJZY_BIANH    VARCHAR(32) NOT NULL,
  WJZY_MINGC   NVARCHAR(32) NOT NULL,
  WJZY_LEIX   INT NOT NULL,
  WJZY_ZIYLJ  VARCHAR(255) NOT NULL,
  SYS_SORT             INT,
  SYS_CREATOR          VARCHAR(32) NOT NULL,
  SYS_CREATETIME       DATETIME NOT NULL,
  SYS_MODIFYBY         VARCHAR(32),
  SYS_MODIFYTIME       DATETIME,
  SYS_STATUS           INT  
);
ALTER TABLE CORE_FILESRES
  ADD CONSTRAINT PK_CORE_FILESRES PRIMARY KEY (RWID);
-- 表模型初始数据
INSERT INTO CORE_TABLES (RWID, MX_MINGC, MX_BIANH,MX_ZHUJZD, MX_BIAOLX, MX_SHIFCJ, SYS_PARENTID ,SYS_PARENTS,SYS_ISLEAF,SYS_SORT, SYS_CREATOR, SYS_CREATETIME, SYS_MODIFYBY, SYS_MODIFYTIME, SYS_STATUS)VALUES('2FEF611CE3A140D7B9C8235BB1C14D22','表模型','TABLEMODEL',NULL,0,1,NULL,'2FEF611CE3A140D7B9C8235BB1C14D22',0,0,'ADMIN',GETDATE(),NULL,NULL,NULL);
INSERT INTO CORE_TABLES (RWID, MX_MINGC, MX_BIANH,MX_ZHUJZD, MX_BIAOLX, MX_SHIFCJ, SYS_PARENTID ,SYS_PARENTS,SYS_ISLEAF,SYS_SORT, SYS_CREATOR, SYS_CREATETIME, SYS_MODIFYBY, SYS_MODIFYTIME, SYS_STATUS)VALUES('394E6660894F4F9F9E39A701CD615C61','平台表模型','CORE',NULL,1,1,'2FEF611CE3A140D7B9C8235BB1C14D22','2FEF611CE3A140D7B9C8235BB1C14D22_394E6660894F4F9F9E39A701CD615C61',0,0,'ADMIN',GETDATE(),NULL,NULL,NULL);

-- 表模型主表
INSERT INTO CORE_TABLES (RWID, MX_MINGC, MX_BIANH,MX_ZHUJZD, MX_BIAOLX, MX_SHIFCJ, SYS_PARENTID ,SYS_PARENTS,SYS_ISLEAF,SYS_SORT, SYS_CREATOR, SYS_CREATETIME, SYS_MODIFYBY, SYS_MODIFYTIME, SYS_STATUS)VALUES('2107610C30434039B0F894503AF496D5','模型表','CORE_TABLES','RWID',0,1,'394E6660894F4F9F9E39A701CD615C61','2FEF611CE3A140D7B9C8235BB1C14D22_394E6660894F4F9F9E39A701CD615C61_2107610C30434039B0F894503AF496D5',0,0,'ADMIN',GETDATE(),NULL,NULL,NULL);
INSERT INTO CORE_TABLES_COLUMNS (MXZD_SHIFCJ,RWID, MXZD_TABLEID, MXZD_BIANH, MXZD_MINGC, MXZD_YINGWM, MXZD_ZIDLX, MXZD_ZIDCD, MXZD_MIAOS, SYS_SORT, SYS_CREATOR, SYS_CREATETIME, SYS_MODIFYBY, SYS_MODIFYTIME, SYS_STATUS,MXZD_XIAOSJD,MXZD_YUNXWK,MXZD_SHIFWY)VALUES(1,'0941A9BEABDA455B93414B6E7C91DB8A','2107610C30434039B0F894503AF496D5','RWID','主键','',0,NULL,NULL,0,'ADMIN',GETDATE(),NULL,NULL,NULL,0,0,1);
INSERT INTO CORE_TABLES_COLUMNS (MXZD_SHIFCJ,RWID, MXZD_TABLEID, MXZD_BIANH, MXZD_MINGC, MXZD_YINGWM, MXZD_ZIDLX, MXZD_ZIDCD, MXZD_MIAOS, SYS_SORT, SYS_CREATOR, SYS_CREATETIME, SYS_MODIFYBY, SYS_MODIFYTIME, SYS_STATUS,MXZD_XIAOSJD,MXZD_YUNXWK,MXZD_SHIFWY)VALUES(1,'81807BF4DA934D0BBAD56B35AF7DB5D3','2107610C30434039B0F894503AF496D5','MX_BIANH','编号','',2,NULL,NULL,0,'ADMIN',GETDATE(),NULL,NULL,NULL,0,0,0);
INSERT INTO CORE_TABLES_COLUMNS (MXZD_SHIFCJ,RWID, MXZD_TABLEID, MXZD_BIANH, MXZD_MINGC, MXZD_YINGWM, MXZD_ZIDLX, MXZD_ZIDCD, MXZD_MIAOS, SYS_SORT, SYS_CREATOR, SYS_CREATETIME, SYS_MODIFYBY, SYS_MODIFYTIME, SYS_STATUS,MXZD_XIAOSJD,MXZD_YUNXWK,MXZD_SHIFWY)VALUES(1,'8A17EED227B34AE0BC1CF09AC21C8BF2','2107610C30434039B0F894503AF496D5','MX_MINGC','名称','',3,NULL,NULL,0,'ADMIN',GETDATE(),NULL,NULL,NULL,0,1,0);
INSERT INTO CORE_TABLES_COLUMNS (MXZD_SHIFCJ,RWID, MXZD_TABLEID, MXZD_BIANH, MXZD_MINGC, MXZD_YINGWM, MXZD_ZIDLX, MXZD_ZIDCD, MXZD_MIAOS, SYS_SORT, SYS_CREATOR, SYS_CREATETIME, SYS_MODIFYBY, SYS_MODIFYTIME, SYS_STATUS,MXZD_XIAOSJD,MXZD_YUNXWK,MXZD_SHIFWY)VALUES(1,'FF37DFC4D6D24D818936FB7172BCAD20','2107610C30434039B0F894503AF496D5','MX_ZHUJZD','主键字段','',2,NULL,NULL,0,'ADMIN',GETDATE(),NULL,NULL,NULL,0,0,0);
INSERT INTO CORE_TABLES_COLUMNS (MXZD_SHIFCJ,RWID, MXZD_TABLEID, MXZD_BIANH, MXZD_MINGC, MXZD_YINGWM, MXZD_ZIDLX, MXZD_ZIDCD, MXZD_MIAOS, SYS_SORT, SYS_CREATOR, SYS_CREATETIME, SYS_MODIFYBY, SYS_MODIFYTIME, SYS_STATUS,MXZD_XIAOSJD,MXZD_YUNXWK,MXZD_SHIFWY)VALUES(1,'A91BAB2D2ECF43D687A0514478E6C780','2107610C30434039B0F894503AF496D5','MX_BIAOLX','表类型','',8,NULL,NULL,0,'ADMIN',GETDATE(),NULL,NULL,NULL,0,1,0);
INSERT INTO CORE_TABLES_COLUMNS (MXZD_SHIFCJ,RWID, MXZD_TABLEID, MXZD_BIANH, MXZD_MINGC, MXZD_YINGWM, MXZD_ZIDLX, MXZD_ZIDCD, MXZD_MIAOS, SYS_SORT, SYS_CREATOR, SYS_CREATETIME, SYS_MODIFYBY, SYS_MODIFYTIME, SYS_STATUS,MXZD_XIAOSJD,MXZD_YUNXWK,MXZD_SHIFWY)VALUES(1,'7BC21DCADFDB46199D2F36449EA8908B','2107610C30434039B0F894503AF496D5','MX_SHIFCJ','是否创建','',8,NULL,NULL,0,'ADMIN',GETDATE(),NULL,NULL,NULL,0,1,0);
INSERT INTO CORE_TABLES_COLUMNS (MXZD_SHIFCJ,RWID, MXZD_TABLEID, MXZD_BIANH, MXZD_MINGC, MXZD_YINGWM, MXZD_ZIDLX, MXZD_ZIDCD, MXZD_MIAOS, SYS_SORT, SYS_CREATOR, SYS_CREATETIME, SYS_MODIFYBY, SYS_MODIFYTIME, SYS_STATUS,MXZD_XIAOSJD,MXZD_YUNXWK,MXZD_SHIFWY)VALUES(1,'A721FF7AB9A3494FB85EBE0723EA5104','2107610C30434039B0F894503AF496D5','SYS_PARENTID','父节点','',1,NULL,NULL,0,'ADMIN',GETDATE(),NULL,NULL,NULL,0,1,0);
INSERT INTO CORE_TABLES_COLUMNS (MXZD_SHIFCJ,RWID, MXZD_TABLEID, MXZD_BIANH, MXZD_MINGC, MXZD_YINGWM, MXZD_ZIDLX, MXZD_ZIDCD, MXZD_MIAOS, SYS_SORT, SYS_CREATOR, SYS_CREATETIME, SYS_MODIFYBY, SYS_MODIFYTIME, SYS_STATUS,MXZD_XIAOSJD,MXZD_YUNXWK,MXZD_SHIFWY)VALUES(1,'14BC0262AD154AB9979F95C31F046B91','2107610C30434039B0F894503AF496D5','SYS_PARENTS','节点路径','',3,NULL,NULL,0,'ADMIN',GETDATE(),NULL,NULL,NULL,0,1,0);
INSERT INTO CORE_TABLES_COLUMNS (MXZD_SHIFCJ,RWID, MXZD_TABLEID, MXZD_BIANH, MXZD_MINGC, MXZD_YINGWM, MXZD_ZIDLX, MXZD_ZIDCD, MXZD_MIAOS, SYS_SORT, SYS_CREATOR, SYS_CREATETIME, SYS_MODIFYBY, SYS_MODIFYTIME, SYS_STATUS,MXZD_XIAOSJD,MXZD_YUNXWK,MXZD_SHIFWY)VALUES(1,'DBC848C48763488CBF9B6B76F47C9B6B','2107610C30434039B0F894503AF496D5','SYS_ISLEAF','是否叶子','',8,NULL,NULL,0,'ADMIN',GETDATE(),NULL,NULL,NULL,0,1,0);
INSERT INTO CORE_TABLES_COLUMNS (MXZD_SHIFCJ,RWID, MXZD_TABLEID, MXZD_BIANH, MXZD_MINGC, MXZD_YINGWM, MXZD_ZIDLX, MXZD_ZIDCD, MXZD_MIAOS, SYS_SORT, SYS_CREATOR, SYS_CREATETIME, SYS_MODIFYBY, SYS_MODIFYTIME, SYS_STATUS,MXZD_XIAOSJD,MXZD_YUNXWK,MXZD_SHIFWY)VALUES(1,'E81FE7CBFD4D49029C051B43A032FAED','2107610C30434039B0F894503AF496D5','SYS_SORT','排序','',9,NULL,NULL,0,'ADMIN',GETDATE(),NULL,NULL,NULL,0,1,0);
INSERT INTO CORE_TABLES_COLUMNS (MXZD_SHIFCJ,RWID, MXZD_TABLEID, MXZD_BIANH, MXZD_MINGC, MXZD_YINGWM, MXZD_ZIDLX, MXZD_ZIDCD, MXZD_MIAOS, SYS_SORT, SYS_CREATOR, SYS_CREATETIME, SYS_MODIFYBY, SYS_MODIFYTIME, SYS_STATUS,MXZD_XIAOSJD,MXZD_YUNXWK,MXZD_SHIFWY)VALUES(1,'DF8FA939A91942BC8663369DD351D549','2107610C30434039B0F894503AF496D5','SYS_CREATOR','创建人','',1,NULL,NULL,0,'ADMIN',GETDATE(),NULL,NULL,NULL,0,1,0);
INSERT INTO CORE_TABLES_COLUMNS (MXZD_SHIFCJ,RWID, MXZD_TABLEID, MXZD_BIANH, MXZD_MINGC, MXZD_YINGWM, MXZD_ZIDLX, MXZD_ZIDCD, MXZD_MIAOS, SYS_SORT, SYS_CREATOR, SYS_CREATETIME, SYS_MODIFYBY, SYS_MODIFYTIME, SYS_STATUS,MXZD_XIAOSJD,MXZD_YUNXWK,MXZD_SHIFWY)VALUES(1,'F04B4FF943A24FF9A9C60A4E92AED197','2107610C30434039B0F894503AF496D5','SYS_CREATETIME','创建时间','',12,NULL,NULL,0,'ADMIN',GETDATE(),NULL,NULL,NULL,0,1,0);
INSERT INTO CORE_TABLES_COLUMNS (MXZD_SHIFCJ,RWID, MXZD_TABLEID, MXZD_BIANH, MXZD_MINGC, MXZD_YINGWM, MXZD_ZIDLX, MXZD_ZIDCD, MXZD_MIAOS, SYS_SORT, SYS_CREATOR, SYS_CREATETIME, SYS_MODIFYBY, SYS_MODIFYTIME, SYS_STATUS,MXZD_XIAOSJD,MXZD_YUNXWK,MXZD_SHIFWY)VALUES(1,'873428FD3B3048F7B01E429D092B6913','2107610C30434039B0F894503AF496D5','SYS_MODIFYBY','修改人','',1,NULL,NULL,0,'ADMIN',GETDATE(),NULL,NULL,NULL,0,1,0);
INSERT INTO CORE_TABLES_COLUMNS (MXZD_SHIFCJ,RWID, MXZD_TABLEID, MXZD_BIANH, MXZD_MINGC, MXZD_YINGWM, MXZD_ZIDLX, MXZD_ZIDCD, MXZD_MIAOS, SYS_SORT, SYS_CREATOR, SYS_CREATETIME, SYS_MODIFYBY, SYS_MODIFYTIME, SYS_STATUS,MXZD_XIAOSJD,MXZD_YUNXWK,MXZD_SHIFWY)VALUES(1,'12C0BCD84BE44AE98A2E1E76CA481FA5','2107610C30434039B0F894503AF496D5','SYS_MODIFYTIME','修改时间','',12,NULL,NULL,0,'ADMIN',GETDATE(),NULL,NULL,NULL,0,1,0);
INSERT INTO CORE_TABLES_COLUMNS (MXZD_SHIFCJ,RWID, MXZD_TABLEID, MXZD_BIANH, MXZD_MINGC, MXZD_YINGWM, MXZD_ZIDLX, MXZD_ZIDCD, MXZD_MIAOS, SYS_SORT, SYS_CREATOR, SYS_CREATETIME, SYS_MODIFYBY, SYS_MODIFYTIME, SYS_STATUS,MXZD_XIAOSJD,MXZD_YUNXWK,MXZD_SHIFWY)VALUES(1,'062492E3029441C99A619CF4F58CD194','2107610C30434039B0F894503AF496D5','SYS_STATUS','状态','',8,NULL,NULL,0,'ADMIN',GETDATE(),NULL,NULL,NULL,0,1,0);

-- 表列表
INSERT INTO CORE_TABLES (RWID, MX_MINGC, MX_BIANH,MX_ZHUJZD, MX_BIAOLX, MX_SHIFCJ, SYS_PARENTID ,SYS_PARENTS,SYS_ISLEAF,SYS_SORT, SYS_CREATOR, SYS_CREATETIME, SYS_MODIFYBY, SYS_MODIFYTIME, SYS_STATUS)VALUES('845B961AE5E74CBE94B5DEDD035C4CE9','模型字段','CORE_TABLES_COLUMNS','MXZD_TABLEID',0,1,'394E6660894F4F9F9E39A701CD615C61','2FEF611CE3A140D7B9C8235BB1C14D22_394E6660894F4F9F9E39A701CD615C61_2107610C30434039B0F894503AF496D5',0,0,'ADMIN',GETDATE(),NULL,NULL,NULL);
INSERT INTO CORE_TABLES_COLUMNS (MXZD_SHIFCJ,RWID, MXZD_TABLEID, MXZD_BIANH, MXZD_MINGC, MXZD_YINGWM, MXZD_ZIDLX, MXZD_ZIDCD, MXZD_MIAOS, SYS_SORT, SYS_CREATOR, SYS_CREATETIME, SYS_MODIFYBY, SYS_MODIFYTIME, SYS_STATUS,MXZD_XIAOSJD,MXZD_YUNXWK,MXZD_SHIFWY)VALUES(1,'EE66414BD4F148BE9006353C3B39243B','845B961AE5E74CBE94B5DEDD035C4CE9','RWID','主键','',0,NULL,NULL,0,'ADMIN',GETDATE(),NULL,NULL,NULL,0,0,0);
INSERT INTO CORE_TABLES_COLUMNS (MXZD_SHIFCJ,RWID, MXZD_TABLEID, MXZD_BIANH, MXZD_MINGC, MXZD_YINGWM, MXZD_ZIDLX, MXZD_ZIDCD, MXZD_MIAOS, SYS_SORT, SYS_CREATOR, SYS_CREATETIME, SYS_MODIFYBY, SYS_MODIFYTIME, SYS_STATUS,MXZD_XIAOSJD,MXZD_YUNXWK,MXZD_SHIFWY)VALUES(1,'1E66414BD4F148BE9006353C3B39243B','845B961AE5E74CBE94B5DEDD035C4CE9','MXZD_TABLEID','外键','',1,NULL,NULL,0,'ADMIN',GETDATE(),NULL,NULL,NULL,0,1,1);
INSERT INTO CORE_TABLES_COLUMNS (MXZD_SHIFCJ,RWID, MXZD_TABLEID, MXZD_BIANH, MXZD_MINGC, MXZD_YINGWM, MXZD_ZIDLX, MXZD_ZIDCD, MXZD_MIAOS, SYS_SORT, SYS_CREATOR, SYS_CREATETIME, SYS_MODIFYBY, SYS_MODIFYTIME, SYS_STATUS,MXZD_XIAOSJD,MXZD_YUNXWK,MXZD_SHIFWY)VALUES(1,'2E66414BD4F148BE9006353C3B39243B','845B961AE5E74CBE94B5DEDD035C4CE9','MXZD_BIANH','编号','',2,NULL,NULL,0,'ADMIN',GETDATE(),NULL,NULL,NULL,0,0,0);
INSERT INTO CORE_TABLES_COLUMNS (MXZD_SHIFCJ,RWID, MXZD_TABLEID, MXZD_BIANH, MXZD_MINGC, MXZD_YINGWM, MXZD_ZIDLX, MXZD_ZIDCD, MXZD_MIAOS, SYS_SORT, SYS_CREATOR, SYS_CREATETIME, SYS_MODIFYBY, SYS_MODIFYTIME, SYS_STATUS,MXZD_XIAOSJD,MXZD_YUNXWK,MXZD_SHIFWY)VALUES(1,'3E66414BD4F148BE9006353C3B39243B','845B961AE5E74CBE94B5DEDD035C4CE9','MXZD_MINGC','名称','',3,NULL,NULL,0,'ADMIN',GETDATE(),NULL,NULL,NULL,0,1,0);
INSERT INTO CORE_TABLES_COLUMNS (MXZD_SHIFCJ,RWID, MXZD_TABLEID, MXZD_BIANH, MXZD_MINGC, MXZD_YINGWM, MXZD_ZIDLX, MXZD_ZIDCD, MXZD_MIAOS, SYS_SORT, SYS_CREATOR, SYS_CREATETIME, SYS_MODIFYBY, SYS_MODIFYTIME, SYS_STATUS,MXZD_XIAOSJD,MXZD_YUNXWK,MXZD_SHIFWY)VALUES(1,'4E66414BD4F148BE9006353C3B39243B','845B961AE5E74CBE94B5DEDD035C4CE9','MXZD_YINGWM','英文','',2,NULL,NULL,0,'ADMIN',GETDATE(),NULL,NULL,NULL,0,0,0);
INSERT INTO CORE_TABLES_COLUMNS (MXZD_SHIFCJ,RWID, MXZD_TABLEID, MXZD_BIANH, MXZD_MINGC, MXZD_YINGWM, MXZD_ZIDLX, MXZD_ZIDCD, MXZD_MIAOS, SYS_SORT, SYS_CREATOR, SYS_CREATETIME, SYS_MODIFYBY, SYS_MODIFYTIME, SYS_STATUS,MXZD_XIAOSJD,MXZD_YUNXWK,MXZD_SHIFWY)VALUES(1,'5E66414BD4F148BE9006353C3B39243B','845B961AE5E74CBE94B5DEDD035C4CE9','MXZD_ZIDLX','字段类型','',8,NULL,NULL,0,'ADMIN',GETDATE(),NULL,NULL,NULL,0,1,0);
INSERT INTO CORE_TABLES_COLUMNS (MXZD_SHIFCJ,RWID, MXZD_TABLEID, MXZD_BIANH, MXZD_MINGC, MXZD_YINGWM, MXZD_ZIDLX, MXZD_ZIDCD, MXZD_MIAOS, SYS_SORT, SYS_CREATOR, SYS_CREATETIME, SYS_MODIFYBY, SYS_MODIFYTIME, SYS_STATUS,MXZD_XIAOSJD,MXZD_YUNXWK,MXZD_SHIFWY)VALUES(1,'6E66414BD4F148BE9006353C3B39243B','845B961AE5E74CBE94B5DEDD035C4CE9','MXZD_ZIDCD','长度','',8,NULL,NULL,0,'ADMIN',GETDATE(),NULL,NULL,NULL,0,0,0);
INSERT INTO CORE_TABLES_COLUMNS (MXZD_SHIFCJ,RWID, MXZD_TABLEID, MXZD_BIANH, MXZD_MINGC, MXZD_YINGWM, MXZD_ZIDLX, MXZD_ZIDCD, MXZD_MIAOS, SYS_SORT, SYS_CREATOR, SYS_CREATETIME, SYS_MODIFYBY, SYS_MODIFYTIME, SYS_STATUS,MXZD_XIAOSJD,MXZD_YUNXWK,MXZD_SHIFWY)VALUES(1,'7E66414BD4F148BE9006353C3B39243B','845B961AE5E74CBE94B5DEDD035C4CE9','MXZD_MIAOS','描述','',4,64,NULL,0,'ADMIN',GETDATE(),NULL,NULL,NULL,0,1,0);
INSERT INTO CORE_TABLES_COLUMNS (MXZD_SHIFCJ,RWID, MXZD_TABLEID, MXZD_BIANH, MXZD_MINGC, MXZD_YINGWM, MXZD_ZIDLX, MXZD_ZIDCD, MXZD_MIAOS, SYS_SORT, SYS_CREATOR, SYS_CREATETIME, SYS_MODIFYBY, SYS_MODIFYTIME, SYS_STATUS,MXZD_XIAOSJD,MXZD_YUNXWK,MXZD_SHIFWY)VALUES(1,'8E66414BD4F148BE9006353C3B39243B','845B961AE5E74CBE94B5DEDD035C4CE9','MXZD_XIAOSJD','小数精度','',8,NULL,NULL,0,'ADMIN',GETDATE(),NULL,NULL,NULL,0,0,0);
INSERT INTO CORE_TABLES_COLUMNS (MXZD_SHIFCJ,RWID, MXZD_TABLEID, MXZD_BIANH, MXZD_MINGC, MXZD_YINGWM, MXZD_ZIDLX, MXZD_ZIDCD, MXZD_MIAOS, SYS_SORT, SYS_CREATOR, SYS_CREATETIME, SYS_MODIFYBY, SYS_MODIFYTIME, SYS_STATUS,MXZD_XIAOSJD,MXZD_YUNXWK,MXZD_SHIFWY)VALUES(1,'9E66414BD4F148BE9006353C3B39243B','845B961AE5E74CBE94B5DEDD035C4CE9','MXZD_YUNXWK','允许为空','',8,NULL,NULL,0,'ADMIN',GETDATE(),NULL,NULL,NULL,0,1,0);
INSERT INTO CORE_TABLES_COLUMNS (MXZD_SHIFCJ,RWID, MXZD_TABLEID, MXZD_BIANH, MXZD_MINGC, MXZD_YINGWM, MXZD_ZIDLX, MXZD_ZIDCD, MXZD_MIAOS, SYS_SORT, SYS_CREATOR, SYS_CREATETIME, SYS_MODIFYBY, SYS_MODIFYTIME, SYS_STATUS,MXZD_XIAOSJD,MXZD_YUNXWK,MXZD_SHIFWY)VALUES(1,'AE66414BD4F148BE9006353C3B39243B','845B961AE5E74CBE94B5DEDD035C4CE9','MXZD_SHIFWY','唯一','',8,NULL,NULL,0,'ADMIN',GETDATE(),NULL,NULL,NULL,4,0,0);
INSERT INTO CORE_TABLES_COLUMNS (MXZD_SHIFCJ,RWID, MXZD_TABLEID, MXZD_BIANH, MXZD_MINGC, MXZD_YINGWM, MXZD_ZIDLX, MXZD_ZIDCD, MXZD_MIAOS, SYS_SORT, SYS_CREATOR, SYS_CREATETIME, SYS_MODIFYBY, SYS_MODIFYTIME, SYS_STATUS,MXZD_XIAOSJD,MXZD_YUNXWK,MXZD_SHIFWY)VALUES(1,'BE66414BD4F148BE9006353C3B39243B','845B961AE5E74CBE94B5DEDD035C4CE9','MXZD_SHIFCJ','是否创建','',8,NULL,NULL,0,'ADMIN',GETDATE(),NULL,NULL,NULL,0,1,0);
INSERT INTO CORE_TABLES_COLUMNS (MXZD_SHIFCJ,RWID, MXZD_TABLEID, MXZD_BIANH, MXZD_MINGC, MXZD_YINGWM, MXZD_ZIDLX, MXZD_ZIDCD, MXZD_MIAOS, SYS_SORT, SYS_CREATOR, SYS_CREATETIME, SYS_MODIFYBY, SYS_MODIFYTIME, SYS_STATUS,MXZD_XIAOSJD,MXZD_YUNXWK,MXZD_SHIFWY)VALUES(1,'8D9383F51E1A4BB487659DE486C44069','845B961AE5E74CBE94B5DEDD035C4CE9','SYS_SORT','排序','',9,NULL,NULL,0,'ADMIN',GETDATE(),NULL,NULL,NULL,0,1,0);
INSERT INTO CORE_TABLES_COLUMNS (MXZD_SHIFCJ,RWID, MXZD_TABLEID, MXZD_BIANH, MXZD_MINGC, MXZD_YINGWM, MXZD_ZIDLX, MXZD_ZIDCD, MXZD_MIAOS, SYS_SORT, SYS_CREATOR, SYS_CREATETIME, SYS_MODIFYBY, SYS_MODIFYTIME, SYS_STATUS,MXZD_XIAOSJD,MXZD_YUNXWK,MXZD_SHIFWY)VALUES(1,'62E568F622CB4E55ACF39FA06DE34D70','845B961AE5E74CBE94B5DEDD035C4CE9','SYS_CREATOR','创建人','',1,NULL,NULL,0,'ADMIN',GETDATE(),NULL,NULL,NULL,0,1,0);
INSERT INTO CORE_TABLES_COLUMNS (MXZD_SHIFCJ,RWID, MXZD_TABLEID, MXZD_BIANH, MXZD_MINGC, MXZD_YINGWM, MXZD_ZIDLX, MXZD_ZIDCD, MXZD_MIAOS, SYS_SORT, SYS_CREATOR, SYS_CREATETIME, SYS_MODIFYBY, SYS_MODIFYTIME, SYS_STATUS,MXZD_XIAOSJD,MXZD_YUNXWK,MXZD_SHIFWY)VALUES(1,'DF115B326D4D4B518A61198CB23A30FD','845B961AE5E74CBE94B5DEDD035C4CE9','SYS_CREATETIME','创建时间','',12,NULL,NULL,0,'ADMIN',GETDATE(),NULL,NULL,NULL,0,1,0);
INSERT INTO CORE_TABLES_COLUMNS (MXZD_SHIFCJ,RWID, MXZD_TABLEID, MXZD_BIANH, MXZD_MINGC, MXZD_YINGWM, MXZD_ZIDLX, MXZD_ZIDCD, MXZD_MIAOS, SYS_SORT, SYS_CREATOR, SYS_CREATETIME, SYS_MODIFYBY, SYS_MODIFYTIME, SYS_STATUS,MXZD_XIAOSJD,MXZD_YUNXWK,MXZD_SHIFWY)VALUES(1,'EDE5A6123E51453B9C270DCFDBAE7DD0','845B961AE5E74CBE94B5DEDD035C4CE9','SYS_MODIFYBY','修改人','',1,NULL,NULL,0,'ADMIN',GETDATE(),NULL,NULL,NULL,0,1,0);
INSERT INTO CORE_TABLES_COLUMNS (MXZD_SHIFCJ,RWID, MXZD_TABLEID, MXZD_BIANH, MXZD_MINGC, MXZD_YINGWM, MXZD_ZIDLX, MXZD_ZIDCD, MXZD_MIAOS, SYS_SORT, SYS_CREATOR, SYS_CREATETIME, SYS_MODIFYBY, SYS_MODIFYTIME, SYS_STATUS,MXZD_XIAOSJD,MXZD_YUNXWK,MXZD_SHIFWY)VALUES(1,'4F9C5DE3A1A349F78EF0598CC1A23557','845B961AE5E74CBE94B5DEDD035C4CE9','SYS_MODIFYTIME','修改时间','',12,NULL,NULL,0,'ADMIN',GETDATE(),NULL,NULL,NULL,0,1,0);
INSERT INTO CORE_TABLES_COLUMNS (MXZD_SHIFCJ,RWID, MXZD_TABLEID, MXZD_BIANH, MXZD_MINGC, MXZD_YINGWM, MXZD_ZIDLX, MXZD_ZIDCD, MXZD_MIAOS, SYS_SORT, SYS_CREATOR, SYS_CREATETIME, SYS_MODIFYBY, SYS_MODIFYTIME, SYS_STATUS,MXZD_XIAOSJD,MXZD_YUNXWK,MXZD_SHIFWY)VALUES(1,'13C52703C5B9442FAC71102D74D05259','845B961AE5E74CBE94B5DEDD035C4CE9','SYS_STATUS','状态','',8,NULL,NULL,0,'ADMIN',GETDATE(),NULL,NULL,NULL,0,1,0);

-- 外联连接
-- INSERT INTO CORE_TABLES_LINKS(RWID, MXYS_TABLEID, MXYS_BIANH , MXYS_XUYGLZD, MXYS_GUANLB, MXYS_GUANLBZD, MXYS_GUANLBLX, SYS_SORT, SYS_CREATOR, SYS_CREATETIME)VALUES('F237AB25F8754EC1AC5824E3149A1BD2','2107610C30434039B0F894503AF496D5','FK_TEST_1','TEST_ID','TEST1','COLUMN1',0,0,'ADMIN',GETDATE());

-- 索引
-- INSERT INTO CORE_TABLES_INDEXS (RWID, MXSY_TABLEID, MXSY_BIANH , MXSY_ZIDLB, MXSY_SHIFWY, SYS_CREATOR, SYS_CREATETIME)VALUES('EE463ABE254240919C613CDB70F2EDAA','2107610C30434039B0F894503AF496D5','IX_TEST_1','column9',0,'ADMIN',GETDATE());

-- 索引表
INSERT INTO CORE_TABLES (RWID, MX_MINGC, MX_BIANH,MX_ZHUJZD, MX_BIAOLX, MX_SHIFCJ, SYS_PARENTID ,SYS_PARENTS,SYS_ISLEAF,SYS_SORT, SYS_CREATOR, SYS_CREATETIME, SYS_MODIFYBY, SYS_MODIFYTIME, SYS_STATUS)VALUES('5B97C1F73A36430A9D81936D21EFE18E','模型索引','CORE_TABLES_INDEXS','RWID',0,1,'394E6660894F4F9F9E39A701CD615C61','2FEF611CE3A140D7B9C8235BB1C14D22_394E6660894F4F9F9E39A701CD615C61_2107610C30434039B0F894503AF496D5',0,0,'ADMIN',GETDATE(),NULL,NULL,NULL);
INSERT INTO CORE_TABLES_COLUMNS (MXZD_SHIFCJ,RWID, MXZD_TABLEID, MXZD_BIANH, MXZD_MINGC, MXZD_YINGWM, MXZD_ZIDLX, MXZD_ZIDCD, MXZD_MIAOS, SYS_SORT, SYS_CREATOR, SYS_CREATETIME, SYS_MODIFYBY, SYS_MODIFYTIME, SYS_STATUS,MXZD_XIAOSJD,MXZD_YUNXWK,MXZD_SHIFWY)VALUES(1,'E51E02E7F972498088E4637BAD19FA32','5B97C1F73A36430A9D81936D21EFE18E','RWID','主键','',0,NULL,NULL,0,'ADMIN',GETDATE(),NULL,NULL,NULL,0,0,0);
INSERT INTO CORE_TABLES_COLUMNS (MXZD_SHIFCJ,RWID, MXZD_TABLEID, MXZD_BIANH, MXZD_MINGC, MXZD_YINGWM, MXZD_ZIDLX, MXZD_ZIDCD, MXZD_MIAOS, SYS_SORT, SYS_CREATOR, SYS_CREATETIME, SYS_MODIFYBY, SYS_MODIFYTIME, SYS_STATUS,MXZD_XIAOSJD,MXZD_YUNXWK,MXZD_SHIFWY)VALUES(1,'54D2CE27632A4A19921BEC0F4ADC6B1F','5B97C1F73A36430A9D81936D21EFE18E','MXSY_TABLEID','外键','',1,NULL,NULL,0,'ADMIN',GETDATE(),NULL,NULL,NULL,0,1,1);
INSERT INTO CORE_TABLES_COLUMNS (MXZD_SHIFCJ,RWID, MXZD_TABLEID, MXZD_BIANH, MXZD_MINGC, MXZD_YINGWM, MXZD_ZIDLX, MXZD_ZIDCD, MXZD_MIAOS, SYS_SORT, SYS_CREATOR, SYS_CREATETIME, SYS_MODIFYBY, SYS_MODIFYTIME, SYS_STATUS,MXZD_XIAOSJD,MXZD_YUNXWK,MXZD_SHIFWY)VALUES(1,'6851009718674C5D95A328137922AD9C','5B97C1F73A36430A9D81936D21EFE18E','MXSY_BIANH','编号','',2,NULL,NULL,0,'ADMIN',GETDATE(),NULL,NULL,NULL,0,0,0);
INSERT INTO CORE_TABLES_COLUMNS (MXZD_SHIFCJ,RWID, MXZD_TABLEID, MXZD_BIANH, MXZD_MINGC, MXZD_YINGWM, MXZD_ZIDLX, MXZD_ZIDCD, MXZD_MIAOS, SYS_SORT, SYS_CREATOR, SYS_CREATETIME, SYS_MODIFYBY, SYS_MODIFYTIME, SYS_STATUS,MXZD_XIAOSJD,MXZD_YUNXWK,MXZD_SHIFWY)VALUES(1,'B706F28D4F8345DF927993BE68BCF930','5B97C1F73A36430A9D81936D21EFE18E','MXSY_ZIDLB','字段列表','',3,NULL,NULL,0,'ADMIN',GETDATE(),NULL,NULL,NULL,0,1,0);
INSERT INTO CORE_TABLES_COLUMNS (MXZD_SHIFCJ,RWID, MXZD_TABLEID, MXZD_BIANH, MXZD_MINGC, MXZD_YINGWM, MXZD_ZIDLX, MXZD_ZIDCD, MXZD_MIAOS, SYS_SORT, SYS_CREATOR, SYS_CREATETIME, SYS_MODIFYBY, SYS_MODIFYTIME, SYS_STATUS,MXZD_XIAOSJD,MXZD_YUNXWK,MXZD_SHIFWY)VALUES(1,'281E6FEB883F4952A43AA3C57AA7DB56','5B97C1F73A36430A9D81936D21EFE18E','MXSY_SHIFWY','唯一索引','',2,NULL,NULL,0,'ADMIN',GETDATE(),NULL,NULL,NULL,0,0,0);
INSERT INTO CORE_TABLES_COLUMNS (MXZD_SHIFCJ,RWID, MXZD_TABLEID, MXZD_BIANH, MXZD_MINGC, MXZD_YINGWM, MXZD_ZIDLX, MXZD_ZIDCD, MXZD_MIAOS, SYS_SORT, SYS_CREATOR, SYS_CREATETIME, SYS_MODIFYBY, SYS_MODIFYTIME, SYS_STATUS,MXZD_XIAOSJD,MXZD_YUNXWK,MXZD_SHIFWY)VALUES(1,'DE3E8AE819594C2AB5769C26C0DB05A7','5B97C1F73A36430A9D81936D21EFE18E','SYS_SORT','排序','',9,NULL,NULL,0,'ADMIN',GETDATE(),NULL,NULL,NULL,0,1,0);
INSERT INTO CORE_TABLES_COLUMNS (MXZD_SHIFCJ,RWID, MXZD_TABLEID, MXZD_BIANH, MXZD_MINGC, MXZD_YINGWM, MXZD_ZIDLX, MXZD_ZIDCD, MXZD_MIAOS, SYS_SORT, SYS_CREATOR, SYS_CREATETIME, SYS_MODIFYBY, SYS_MODIFYTIME, SYS_STATUS,MXZD_XIAOSJD,MXZD_YUNXWK,MXZD_SHIFWY)VALUES(1,'D7A863DF92E84F2CA1963477BCCAEBAB','5B97C1F73A36430A9D81936D21EFE18E','SYS_CREATOR','创建人','',1,NULL,NULL,0,'ADMIN',GETDATE(),NULL,NULL,NULL,0,1,0);
INSERT INTO CORE_TABLES_COLUMNS (MXZD_SHIFCJ,RWID, MXZD_TABLEID, MXZD_BIANH, MXZD_MINGC, MXZD_YINGWM, MXZD_ZIDLX, MXZD_ZIDCD, MXZD_MIAOS, SYS_SORT, SYS_CREATOR, SYS_CREATETIME, SYS_MODIFYBY, SYS_MODIFYTIME, SYS_STATUS,MXZD_XIAOSJD,MXZD_YUNXWK,MXZD_SHIFWY)VALUES(1,'34AB3DCDF475442EBA6BCE2D22659820','5B97C1F73A36430A9D81936D21EFE18E','SYS_CREATETIME','创建时间','',12,NULL,NULL,0,'ADMIN',GETDATE(),NULL,NULL,NULL,0,1,0);
INSERT INTO CORE_TABLES_COLUMNS (MXZD_SHIFCJ,RWID, MXZD_TABLEID, MXZD_BIANH, MXZD_MINGC, MXZD_YINGWM, MXZD_ZIDLX, MXZD_ZIDCD, MXZD_MIAOS, SYS_SORT, SYS_CREATOR, SYS_CREATETIME, SYS_MODIFYBY, SYS_MODIFYTIME, SYS_STATUS,MXZD_XIAOSJD,MXZD_YUNXWK,MXZD_SHIFWY)VALUES(1,'3B48FB20D6324E079139341DCD7D4E18','5B97C1F73A36430A9D81936D21EFE18E','SYS_MODIFYBY','修改人','',1,NULL,NULL,0,'ADMIN',GETDATE(),NULL,NULL,NULL,0,1,0);
INSERT INTO CORE_TABLES_COLUMNS (MXZD_SHIFCJ,RWID, MXZD_TABLEID, MXZD_BIANH, MXZD_MINGC, MXZD_YINGWM, MXZD_ZIDLX, MXZD_ZIDCD, MXZD_MIAOS, SYS_SORT, SYS_CREATOR, SYS_CREATETIME, SYS_MODIFYBY, SYS_MODIFYTIME, SYS_STATUS,MXZD_XIAOSJD,MXZD_YUNXWK,MXZD_SHIFWY)VALUES(1,'4A27540D4DEB4A2795E5E958FA7635FD','5B97C1F73A36430A9D81936D21EFE18E','SYS_MODIFYTIME','修改时间','',12,NULL,NULL,0,'ADMIN',GETDATE(),NULL,NULL,NULL,0,1,0);
INSERT INTO CORE_TABLES_COLUMNS (MXZD_SHIFCJ,RWID, MXZD_TABLEID, MXZD_BIANH, MXZD_MINGC, MXZD_YINGWM, MXZD_ZIDLX, MXZD_ZIDCD, MXZD_MIAOS, SYS_SORT, SYS_CREATOR, SYS_CREATETIME, SYS_MODIFYBY, SYS_MODIFYTIME, SYS_STATUS,MXZD_XIAOSJD,MXZD_YUNXWK,MXZD_SHIFWY)VALUES(1,'D66B1C9F426843EF81984941A102EC2F','5B97C1F73A36430A9D81936D21EFE18E','SYS_STATUS','状态','',8,NULL,NULL,0,'ADMIN',GETDATE(),NULL,NULL,NULL,0,1,0);

-- 约束表
INSERT INTO CORE_TABLES (RWID, MX_MINGC, MX_BIANH,MX_ZHUJZD, MX_BIAOLX, MX_SHIFCJ, SYS_PARENTID ,SYS_PARENTS,SYS_ISLEAF,SYS_SORT, SYS_CREATOR, SYS_CREATETIME, SYS_MODIFYBY, SYS_MODIFYTIME, SYS_STATUS)VALUES('EE8D97EF26E246DEAA878CCF7022012F','模型约束','CORE_TABLES_LINKS','RWID',0,1,'394E6660894F4F9F9E39A701CD615C61','2FEF611CE3A140D7B9C8235BB1C14D22_394E6660894F4F9F9E39A701CD615C61_2107610C30434039B0F894503AF496D5',0,0,'ADMIN',GETDATE(),NULL,NULL,NULL);
INSERT INTO CORE_TABLES_COLUMNS (MXZD_SHIFCJ,RWID, MXZD_TABLEID, MXZD_BIANH, MXZD_MINGC, MXZD_YINGWM, MXZD_ZIDLX, MXZD_ZIDCD, MXZD_MIAOS, SYS_SORT, SYS_CREATOR, SYS_CREATETIME, SYS_MODIFYBY, SYS_MODIFYTIME, SYS_STATUS,MXZD_XIAOSJD,MXZD_YUNXWK,MXZD_SHIFWY)VALUES(1,'984BD02C95BB4A2381AC9365AE9C93A6','EE8D97EF26E246DEAA878CCF7022012F','RWID','主键','',0,NULL,NULL,0,'ADMIN',GETDATE(),NULL,NULL,NULL,0,0,0);
INSERT INTO CORE_TABLES_COLUMNS (MXZD_SHIFCJ,RWID, MXZD_TABLEID, MXZD_BIANH, MXZD_MINGC, MXZD_YINGWM, MXZD_ZIDLX, MXZD_ZIDCD, MXZD_MIAOS, SYS_SORT, SYS_CREATOR, SYS_CREATETIME, SYS_MODIFYBY, SYS_MODIFYTIME, SYS_STATUS,MXZD_XIAOSJD,MXZD_YUNXWK,MXZD_SHIFWY)VALUES(1,'A8106DB5EB2240B3A4D1868CCE4F3313','EE8D97EF26E246DEAA878CCF7022012F','MXYS_TABLEID','外键','',1,NULL,NULL,0,'ADMIN',GETDATE(),NULL,NULL,NULL,0,1,1);
INSERT INTO CORE_TABLES_COLUMNS (MXZD_SHIFCJ,RWID, MXZD_TABLEID, MXZD_BIANH, MXZD_MINGC, MXZD_YINGWM, MXZD_ZIDLX, MXZD_ZIDCD, MXZD_MIAOS, SYS_SORT, SYS_CREATOR, SYS_CREATETIME, SYS_MODIFYBY, SYS_MODIFYTIME, SYS_STATUS,MXZD_XIAOSJD,MXZD_YUNXWK,MXZD_SHIFWY)VALUES(1,'14F64111150B45B08691E928EA0624EA','EE8D97EF26E246DEAA878CCF7022012F','MXYS_BIANH','编号','',2,NULL,NULL,0,'ADMIN',GETDATE(),NULL,NULL,NULL,0,0,0);
INSERT INTO CORE_TABLES_COLUMNS (MXZD_SHIFCJ,RWID, MXZD_TABLEID, MXZD_BIANH, MXZD_MINGC, MXZD_YINGWM, MXZD_ZIDLX, MXZD_ZIDCD, MXZD_MIAOS, SYS_SORT, SYS_CREATOR, SYS_CREATETIME, SYS_MODIFYBY, SYS_MODIFYTIME, SYS_STATUS,MXZD_XIAOSJD,MXZD_YUNXWK,MXZD_SHIFWY)VALUES(1,'DB7912FC17FC49A5B262DB9BF14F6729','EE8D97EF26E246DEAA878CCF7022012F','MXYS_XUYGLZD','需关联字段','',3,NULL,NULL,0,'ADMIN',GETDATE(),NULL,NULL,NULL,0,1,0);
INSERT INTO CORE_TABLES_COLUMNS (MXZD_SHIFCJ,RWID, MXZD_TABLEID, MXZD_BIANH, MXZD_MINGC, MXZD_YINGWM, MXZD_ZIDLX, MXZD_ZIDCD, MXZD_MIAOS, SYS_SORT, SYS_CREATOR, SYS_CREATETIME, SYS_MODIFYBY, SYS_MODIFYTIME, SYS_STATUS,MXZD_XIAOSJD,MXZD_YUNXWK,MXZD_SHIFWY)VALUES(1,'06C89E54AD7349D98F2D3B57BBA8ADAE','EE8D97EF26E246DEAA878CCF7022012F','MXYS_GUANLB','关联的表','',2,NULL,NULL,0,'ADMIN',GETDATE(),NULL,NULL,NULL,0,0,0);
INSERT INTO CORE_TABLES_COLUMNS (MXZD_SHIFCJ,RWID, MXZD_TABLEID, MXZD_BIANH, MXZD_MINGC, MXZD_YINGWM, MXZD_ZIDLX, MXZD_ZIDCD, MXZD_MIAOS, SYS_SORT, SYS_CREATOR, SYS_CREATETIME, SYS_MODIFYBY, SYS_MODIFYTIME, SYS_STATUS,MXZD_XIAOSJD,MXZD_YUNXWK,MXZD_SHIFWY)VALUES(1,'C62C98D4012E4939844DE3110B70AB36','EE8D97EF26E246DEAA878CCF7022012F','MXYS_GUANLBZD','关联的表字段','',2,NULL,NULL,0,'ADMIN',GETDATE(),NULL,NULL,NULL,0,0,0);
INSERT INTO CORE_TABLES_COLUMNS (MXZD_SHIFCJ,RWID, MXZD_TABLEID, MXZD_BIANH, MXZD_MINGC, MXZD_YINGWM, MXZD_ZIDLX, MXZD_ZIDCD, MXZD_MIAOS, SYS_SORT, SYS_CREATOR, SYS_CREATETIME, SYS_MODIFYBY, SYS_MODIFYTIME, SYS_STATUS,MXZD_XIAOSJD,MXZD_YUNXWK,MXZD_SHIFWY)VALUES(1,'1CD7A1A1435E4AEDA03C2620B873C2D6','EE8D97EF26E246DEAA878CCF7022012F','MXYS_GUANLBLX','关联类型','',2,NULL,NULL,0,'ADMIN',GETDATE(),NULL,NULL,NULL,0,0,0);
INSERT INTO CORE_TABLES_COLUMNS (MXZD_SHIFCJ,RWID, MXZD_TABLEID, MXZD_BIANH, MXZD_MINGC, MXZD_YINGWM, MXZD_ZIDLX, MXZD_ZIDCD, MXZD_MIAOS, SYS_SORT, SYS_CREATOR, SYS_CREATETIME, SYS_MODIFYBY, SYS_MODIFYTIME, SYS_STATUS,MXZD_XIAOSJD,MXZD_YUNXWK,MXZD_SHIFWY)VALUES(1,'7ACCB475528B4885AF2BAF8822DE9814','EE8D97EF26E246DEAA878CCF7022012F','SYS_SORT','排序','',9,NULL,NULL,0,'ADMIN',GETDATE(),NULL,NULL,NULL,0,1,0);
INSERT INTO CORE_TABLES_COLUMNS (MXZD_SHIFCJ,RWID, MXZD_TABLEID, MXZD_BIANH, MXZD_MINGC, MXZD_YINGWM, MXZD_ZIDLX, MXZD_ZIDCD, MXZD_MIAOS, SYS_SORT, SYS_CREATOR, SYS_CREATETIME, SYS_MODIFYBY, SYS_MODIFYTIME, SYS_STATUS,MXZD_XIAOSJD,MXZD_YUNXWK,MXZD_SHIFWY)VALUES(1,'3C94D2FFCE874BD98193A48CD0C2AA84','EE8D97EF26E246DEAA878CCF7022012F','SYS_CREATOR','创建人','',1,NULL,NULL,0,'ADMIN',GETDATE(),NULL,NULL,NULL,0,1,0);
INSERT INTO CORE_TABLES_COLUMNS (MXZD_SHIFCJ,RWID, MXZD_TABLEID, MXZD_BIANH, MXZD_MINGC, MXZD_YINGWM, MXZD_ZIDLX, MXZD_ZIDCD, MXZD_MIAOS, SYS_SORT, SYS_CREATOR, SYS_CREATETIME, SYS_MODIFYBY, SYS_MODIFYTIME, SYS_STATUS,MXZD_XIAOSJD,MXZD_YUNXWK,MXZD_SHIFWY)VALUES(1,'58BDAD3D2AFD4F20A141F232F2CBADBC','EE8D97EF26E246DEAA878CCF7022012F','SYS_CREATETIME','创建时间','',12,NULL,NULL,0,'ADMIN',GETDATE(),NULL,NULL,NULL,0,1,0);
INSERT INTO CORE_TABLES_COLUMNS (MXZD_SHIFCJ,RWID, MXZD_TABLEID, MXZD_BIANH, MXZD_MINGC, MXZD_YINGWM, MXZD_ZIDLX, MXZD_ZIDCD, MXZD_MIAOS, SYS_SORT, SYS_CREATOR, SYS_CREATETIME, SYS_MODIFYBY, SYS_MODIFYTIME, SYS_STATUS,MXZD_XIAOSJD,MXZD_YUNXWK,MXZD_SHIFWY)VALUES(1,'C55114B1ADBE4C4A83563323C295C77B','EE8D97EF26E246DEAA878CCF7022012F','SYS_MODIFYBY','修改人','',1,NULL,NULL,0,'ADMIN',GETDATE(),NULL,NULL,NULL,0,1,0);
INSERT INTO CORE_TABLES_COLUMNS (MXZD_SHIFCJ,RWID, MXZD_TABLEID, MXZD_BIANH, MXZD_MINGC, MXZD_YINGWM, MXZD_ZIDLX, MXZD_ZIDCD, MXZD_MIAOS, SYS_SORT, SYS_CREATOR, SYS_CREATETIME, SYS_MODIFYBY, SYS_MODIFYTIME, SYS_STATUS,MXZD_XIAOSJD,MXZD_YUNXWK,MXZD_SHIFWY)VALUES(1,'D5D1C4F311034E5381594B4B27DC2B26','EE8D97EF26E246DEAA878CCF7022012F','SYS_MODIFYTIME','修改时间','',12,NULL,NULL,0,'ADMIN',GETDATE(),NULL,NULL,NULL,0,1,0);
INSERT INTO CORE_TABLES_COLUMNS (MXZD_SHIFCJ,RWID, MXZD_TABLEID, MXZD_BIANH, MXZD_MINGC, MXZD_YINGWM, MXZD_ZIDLX, MXZD_ZIDCD, MXZD_MIAOS, SYS_SORT, SYS_CREATOR, SYS_CREATETIME, SYS_MODIFYBY, SYS_MODIFYTIME, SYS_STATUS,MXZD_XIAOSJD,MXZD_YUNXWK,MXZD_SHIFWY)VALUES(1,'EE77F6DCB1004317B49055530EB53414','EE8D97EF26E246DEAA878CCF7022012F','SYS_STATUS','状态','',8,NULL,NULL,0,'ADMIN',GETDATE(),NULL,NULL,NULL,0,1,0);

--文件资源表
INSERT INTO CORE_TABLES (RWID, MX_MINGC, MX_BIANH,MX_ZHUJZD, MX_BIAOLX, MX_SHIFCJ, SYS_PARENTID ,SYS_PARENTS,SYS_ISLEAF,SYS_SORT, SYS_CREATOR, SYS_CREATETIME, SYS_MODIFYBY, SYS_MODIFYTIME, SYS_STATUS)VALUES('D4AB77C149154C97A5168009DC55210D','文件资源','CORE_TABLES_INDEXS','RWID',0,1,'394E6660894F4F9F9E39A701CD615C61','2FEF611CE3A140D7B9C8235BB1C14D22_394E6660894F4F9F9E39A701CD615C61_2107610C30434039B0F894503AF496D5',0,0,'ADMIN',GETDATE(),NULL,NULL,NULL);
INSERT INTO CORE_TABLES_COLUMNS (MXZD_SHIFCJ,RWID, MXZD_TABLEID, MXZD_BIANH, MXZD_MINGC, MXZD_YINGWM, MXZD_ZIDLX, MXZD_ZIDCD, MXZD_MIAOS, SYS_SORT, SYS_CREATOR, SYS_CREATETIME, SYS_MODIFYBY, SYS_MODIFYTIME, SYS_STATUS,MXZD_XIAOSJD,MXZD_YUNXWK,MXZD_SHIFWY)VALUES(1,'8C4C1BBBFEDA4CCBAA687874783447F0','D4AB77C149154C97A5168009DC55210D','CORE_RWID','主键','',0,NULL,NULL,0,'ADMIN',GETDATE(),NULL,NULL,NULL,0,0,0);
INSERT INTO CORE_TABLES_COLUMNS (MXZD_SHIFCJ,RWID, MXZD_TABLEID, MXZD_BIANH, MXZD_MINGC, MXZD_YINGWM, MXZD_ZIDLX, MXZD_ZIDCD, MXZD_MIAOS, SYS_SORT, SYS_CREATOR, SYS_CREATETIME, SYS_MODIFYBY, SYS_MODIFYTIME, SYS_STATUS,MXZD_XIAOSJD,MXZD_YUNXWK,MXZD_SHIFWY)VALUES(1,'160EC31FA7F040178503D5693368D1AA','D4AB77C149154C97A5168009DC55210D','CORE_WJZY_BIANH','编号','',2,NULL,NULL,0,'ADMIN',GETDATE(),NULL,NULL,NULL,0,0,0);
INSERT INTO CORE_TABLES_COLUMNS (MXZD_SHIFCJ,RWID, MXZD_TABLEID, MXZD_BIANH, MXZD_MINGC, MXZD_YINGWM, MXZD_ZIDLX, MXZD_ZIDCD, MXZD_MIAOS, SYS_SORT, SYS_CREATOR, SYS_CREATETIME, SYS_MODIFYBY, SYS_MODIFYTIME, SYS_STATUS,MXZD_XIAOSJD,MXZD_YUNXWK,MXZD_SHIFWY)VALUES(1,'FEAECEA7B4CA49279FD2526C785B0A31','D4AB77C149154C97A5168009DC55210D','CORE_FILESS_MC','名称','',3,NULL,NULL,0,'ADMIN',GETDATE(),NULL,NULL,NULL,0,1,0);
INSERT INTO CORE_TABLES_COLUMNS (MXZD_SHIFCJ,RWID, MXZD_TABLEID, MXZD_BIANH, MXZD_MINGC, MXZD_YINGWM, MXZD_ZIDLX, MXZD_ZIDCD, MXZD_MIAOS, SYS_SORT, SYS_CREATOR, SYS_CREATETIME, SYS_MODIFYBY, SYS_MODIFYTIME, SYS_STATUS,MXZD_XIAOSJD,MXZD_YUNXWK,MXZD_SHIFWY)VALUES(1,'EC22912A8B784F35A1DE8FC7287A813A','D4AB77C149154C97A5168009DC55210D','CORE_FILESS_URL','路径','',4,NULL,NULL,0,'ADMIN',GETDATE(),NULL,NULL,NULL,0,0,0);
INSERT INTO CORE_TABLES_COLUMNS (MXZD_SHIFCJ,RWID, MXZD_TABLEID, MXZD_BIANH, MXZD_MINGC, MXZD_YINGWM, MXZD_ZIDLX, MXZD_ZIDCD, MXZD_MIAOS, SYS_SORT, SYS_CREATOR, SYS_CREATETIME, SYS_MODIFYBY, SYS_MODIFYTIME, SYS_STATUS,MXZD_XIAOSJD,MXZD_YUNXWK,MXZD_SHIFWY)VALUES(1,'CA7ECE664F214C46821DB434CC0EED47','D4AB77C149154C97A5168009DC55210D','SYS_SORT','排序','',9,NULL,NULL,0,'ADMIN',GETDATE(),NULL,NULL,NULL,0,1,0);
INSERT INTO CORE_TABLES_COLUMNS (MXZD_SHIFCJ,RWID, MXZD_TABLEID, MXZD_BIANH, MXZD_MINGC, MXZD_YINGWM, MXZD_ZIDLX, MXZD_ZIDCD, MXZD_MIAOS, SYS_SORT, SYS_CREATOR, SYS_CREATETIME, SYS_MODIFYBY, SYS_MODIFYTIME, SYS_STATUS,MXZD_XIAOSJD,MXZD_YUNXWK,MXZD_SHIFWY)VALUES(1,'B4029169BDC94B1B912F7976BB8EB67A','D4AB77C149154C97A5168009DC55210D','SYS_CREATOR','创建人','',1,NULL,NULL,0,'ADMIN',GETDATE(),NULL,NULL,NULL,0,1,0);
INSERT INTO CORE_TABLES_COLUMNS (MXZD_SHIFCJ,RWID, MXZD_TABLEID, MXZD_BIANH, MXZD_MINGC, MXZD_YINGWM, MXZD_ZIDLX, MXZD_ZIDCD, MXZD_MIAOS, SYS_SORT, SYS_CREATOR, SYS_CREATETIME, SYS_MODIFYBY, SYS_MODIFYTIME, SYS_STATUS,MXZD_XIAOSJD,MXZD_YUNXWK,MXZD_SHIFWY)VALUES(1,'6C079BC3356342349043B291651ABDFB','D4AB77C149154C97A5168009DC55210D','SYS_CREATETIME','创建时间','',12,NULL,NULL,0,'ADMIN',GETDATE(),NULL,NULL,NULL,0,1,0);
INSERT INTO CORE_TABLES_COLUMNS (MXZD_SHIFCJ,RWID, MXZD_TABLEID, MXZD_BIANH, MXZD_MINGC, MXZD_YINGWM, MXZD_ZIDLX, MXZD_ZIDCD, MXZD_MIAOS, SYS_SORT, SYS_CREATOR, SYS_CREATETIME, SYS_MODIFYBY, SYS_MODIFYTIME, SYS_STATUS,MXZD_XIAOSJD,MXZD_YUNXWK,MXZD_SHIFWY)VALUES(1,'54486CDBC97D4F2F8B447EE81129C096','D4AB77C149154C97A5168009DC55210D','SYS_MODIFYBY','修改人','',1,NULL,NULL,0,'ADMIN',GETDATE(),NULL,NULL,NULL,0,1,0);
INSERT INTO CORE_TABLES_COLUMNS (MXZD_SHIFCJ,RWID, MXZD_TABLEID, MXZD_BIANH, MXZD_MINGC, MXZD_YINGWM, MXZD_ZIDLX, MXZD_ZIDCD, MXZD_MIAOS, SYS_SORT, SYS_CREATOR, SYS_CREATETIME, SYS_MODIFYBY, SYS_MODIFYTIME, SYS_STATUS,MXZD_XIAOSJD,MXZD_YUNXWK,MXZD_SHIFWY)VALUES(1,'A883097556ED4AAEB1DDE3B29A79577D','D4AB77C149154C97A5168009DC55210D','SYS_MODIFYTIME','修改时间','',12,NULL,NULL,0,'ADMIN',GETDATE(),NULL,NULL,NULL,0,1,0);
INSERT INTO CORE_TABLES_COLUMNS (MXZD_SHIFCJ,RWID, MXZD_TABLEID, MXZD_BIANH, MXZD_MINGC, MXZD_YINGWM, MXZD_ZIDLX, MXZD_ZIDCD, MXZD_MIAOS, SYS_SORT, SYS_CREATOR, SYS_CREATETIME, SYS_MODIFYBY, SYS_MODIFYTIME, SYS_STATUS,MXZD_XIAOSJD,MXZD_YUNXWK,MXZD_SHIFWY)VALUES(1,'2A6BCB5186504BBAA8331E6DF52C94C1','D4AB77C149154C97A5168009DC55210D','SYS_STATUS','状态','',8,NULL,NULL,0,'ADMIN',GETDATE(),NULL,NULL,NULL,0,1,0);


-- 数据库通用字段枚举 DATATYPES
INSERT INTO CORE_DICTIONARY(RWID, ZDMX_BIANH, ZDMX_MINGC, ZDMX_LEIX, ZDMX_GUANLBM, ZDMX_SUOSXT, SYS_SORT, SYS_CREATOR, SYS_CREATETIME, SYS_MODIFYBY, SYS_MODIFYTIME, SYS_STATUS)VALUES('F29725BB1E024C4C8AA2988E4967E971','CORE_DB_DATATYPES','表字段类型','0','','CORE',0,'ADMIN',GETDATE(),NULL,NULL,0);
INSERT INTO CORE_DICTIONARYMX(RWID, ZDZ_DICTIONARYID, ZDZ_MINGC, ZDZ_BIANH, ZDZ_YANGS, ZDZ_SHIFQY, ZDZ_ZIDZ,SYS_SORT, SYS_CREATOR, SYS_CREATETIME, SYS_MODIFYBY, SYS_MODIFYTIME, SYS_STATUS)VALUES('ACCB9DD627B743AF8FAD4E448F4363C0','F29725BB1E024C4C8AA2988E4967E971','主键(64)','PRIMARY KEY',NULL,1,0,0,'ADMIN',GETDATE(),NULL,NULL,NULL);
INSERT INTO CORE_DICTIONARYMX(RWID, ZDZ_DICTIONARYID, ZDZ_MINGC, ZDZ_BIANH, ZDZ_YANGS, ZDZ_SHIFQY, ZDZ_ZIDZ,SYS_SORT, SYS_CREATOR, SYS_CREATETIME, SYS_MODIFYBY, SYS_MODIFYTIME, SYS_STATUS)VALUES('DF6EC06B65A248CDABAAF9BB4FEC491E','F29725BB1E024C4C8AA2988E4967E971','字符串(32)',NULL,NULL,1,1,1,'ADMIN',GETDATE(),NULL,NULL,NULL);
INSERT INTO CORE_DICTIONARYMX(RWID, ZDZ_DICTIONARYID, ZDZ_MINGC, ZDZ_BIANH, ZDZ_YANGS, ZDZ_SHIFQY, ZDZ_ZIDZ,SYS_SORT, SYS_CREATOR, SYS_CREATETIME, SYS_MODIFYBY, SYS_MODIFYTIME, SYS_STATUS)VALUES('AF38A4A06D114CE9AE3EEF0F9A7797D8','F29725BB1E024C4C8AA2988E4967E971','字符串(50)',NULL,NULL,1,2,2,'ADMIN',GETDATE(),NULL,NULL,NULL);
INSERT INTO CORE_DICTIONARYMX(RWID, ZDZ_DICTIONARYID, ZDZ_MINGC, ZDZ_BIANH, ZDZ_YANGS, ZDZ_SHIFQY, ZDZ_ZIDZ,SYS_SORT, SYS_CREATOR, SYS_CREATETIME, SYS_MODIFYBY, SYS_MODIFYTIME, SYS_STATUS)VALUES('F0B60F0E948E4D378CE941AF0D6EF3FA','F29725BB1E024C4C8AA2988E4967E971','字符串(100)',NULL,NULL,1,3,3,'ADMIN',GETDATE(),NULL,NULL,NULL);
INSERT INTO CORE_DICTIONARYMX(RWID, ZDZ_DICTIONARYID, ZDZ_MINGC, ZDZ_BIANH, ZDZ_YANGS, ZDZ_SHIFQY, ZDZ_ZIDZ,SYS_SORT, SYS_CREATOR, SYS_CREATETIME, SYS_MODIFYBY, SYS_MODIFYTIME, SYS_STATUS)VALUES('83246536AFEA4D13B5BECBC8253D3F51','F29725BB1E024C4C8AA2988E4967E971','字符串(255)',NULL,NULL,1,4,4,'ADMIN',GETDATE(),NULL,NULL,NULL);
INSERT INTO CORE_DICTIONARYMX(RWID, ZDZ_DICTIONARYID, ZDZ_MINGC, ZDZ_BIANH, ZDZ_YANGS, ZDZ_SHIFQY, ZDZ_ZIDZ,SYS_SORT, SYS_CREATOR, SYS_CREATETIME, SYS_MODIFYBY, SYS_MODIFYTIME, SYS_STATUS)VALUES('466DB9CB297A4CD3A1D32FA61D5558D9','F29725BB1E024C4C8AA2988E4967E971','字符串(1000)',NULL,NULL,1,5,5,'ADMIN',GETDATE(),NULL,NULL,NULL);
INSERT INTO CORE_DICTIONARYMX(RWID, ZDZ_DICTIONARYID, ZDZ_MINGC, ZDZ_BIANH, ZDZ_YANGS, ZDZ_SHIFQY, ZDZ_ZIDZ,SYS_SORT, SYS_CREATOR, SYS_CREATETIME, SYS_MODIFYBY, SYS_MODIFYTIME, SYS_STATUS)VALUES('791227EFED87440C993BAFB650315CBD','F29725BB1E024C4C8AA2988E4967E971','字符串(2000)',NULL,NULL,1,6,6,'ADMIN',GETDATE(),NULL,NULL,NULL);
INSERT INTO CORE_DICTIONARYMX(RWID, ZDZ_DICTIONARYID, ZDZ_MINGC, ZDZ_BIANH, ZDZ_YANGS, ZDZ_SHIFQY, ZDZ_ZIDZ,SYS_SORT, SYS_CREATOR, SYS_CREATETIME, SYS_MODIFYBY, SYS_MODIFYTIME, SYS_STATUS)VALUES('A167C61DB7994C9E8996F44DE49629A7','F29725BB1E024C4C8AA2988E4967E971','字符串(x)',NULL,NULL,1,7,7,'ADMIN',GETDATE(),NULL,NULL,NULL);
INSERT INTO CORE_DICTIONARYMX(RWID, ZDZ_DICTIONARYID, ZDZ_MINGC, ZDZ_BIANH, ZDZ_YANGS, ZDZ_SHIFQY, ZDZ_ZIDZ,SYS_SORT, SYS_CREATOR, SYS_CREATETIME, SYS_MODIFYBY, SYS_MODIFYTIME, SYS_STATUS)VALUES('7FAD5B164BA4409086682FF87ED24FAB','F29725BB1E024C4C8AA2988E4967E971','整数',NULL,NULL,1,8,8,'ADMIN',GETDATE(),NULL,NULL,NULL);
INSERT INTO CORE_DICTIONARYMX(RWID, ZDZ_DICTIONARYID, ZDZ_MINGC, ZDZ_BIANH, ZDZ_YANGS, ZDZ_SHIFQY, ZDZ_ZIDZ,SYS_SORT, SYS_CREATOR, SYS_CREATETIME, SYS_MODIFYBY, SYS_MODIFYTIME, SYS_STATUS)VALUES('AA04E97904164B21A92D33F2C2B9BAEA','F29725BB1E024C4C8AA2988E4967E971','小数(2)',NULL,NULL,1,9,9,'ADMIN',GETDATE(),NULL,NULL,NULL);
INSERT INTO CORE_DICTIONARYMX(RWID, ZDZ_DICTIONARYID, ZDZ_MINGC, ZDZ_BIANH, ZDZ_YANGS, ZDZ_SHIFQY, ZDZ_ZIDZ,SYS_SORT, SYS_CREATOR, SYS_CREATETIME, SYS_MODIFYBY, SYS_MODIFYTIME, SYS_STATUS)VALUES('73F1481AE4E74E6D8BD9C620CB098F0F','F29725BB1E024C4C8AA2988E4967E971','小数(x)',NULL,NULL,1,10,10,'ADMIN',GETDATE(),NULL,NULL,NULL);
INSERT INTO CORE_DICTIONARYMX(RWID, ZDZ_DICTIONARYID, ZDZ_MINGC, ZDZ_BIANH, ZDZ_YANGS, ZDZ_SHIFQY, ZDZ_ZIDZ,SYS_SORT, SYS_CREATOR, SYS_CREATETIME, SYS_MODIFYBY, SYS_MODIFYTIME, SYS_STATUS)VALUES('C953C9440F474B66B18850DBBD776301','F29725BB1E024C4C8AA2988E4967E971','日期',NULL,NULL,1,11,11,'ADMIN',GETDATE(),NULL,NULL,NULL);
INSERT INTO CORE_DICTIONARYMX(RWID, ZDZ_DICTIONARYID, ZDZ_MINGC, ZDZ_BIANH, ZDZ_YANGS, ZDZ_SHIFQY, ZDZ_ZIDZ,SYS_SORT, SYS_CREATOR, SYS_CREATETIME, SYS_MODIFYBY, SYS_MODIFYTIME, SYS_STATUS)VALUES('FEC888CB86A44183AF1554F49EAB86A8','F29725BB1E024C4C8AA2988E4967E971','日期时间',NULL,NULL,1,12,12,'ADMIN',GETDATE(),NULL,NULL,NULL);

-- ORACLE DATATYPES
INSERT INTO CORE_DICTIONARY(RWID, ZDMX_BIANH, ZDMX_MINGC,  ZDMX_LEIX, ZDMX_GUANLBM, ZDMX_SUOSXT, SYS_SORT, SYS_CREATOR, SYS_CREATETIME, SYS_MODIFYBY, SYS_MODIFYTIME, SYS_STATUS)VALUES('1698BE55F0D4413E81436F6EF27E38D4','CORE_ORACLE_DATATYPES','ORACLE表字段类型','0','','CORE',0,'ADMIN',GETDATE(),NULL,NULL,0);
INSERT INTO CORE_DICTIONARYMX(RWID, ZDZ_DICTIONARYID, ZDZ_MINGC, ZDZ_BIANH, ZDZ_YANGS, ZDZ_SHIFQY, ZDZ_ZIDZ,SYS_SORT, SYS_CREATOR, SYS_CREATETIME, SYS_MODIFYBY, SYS_MODIFYTIME, SYS_STATUS)VALUES('7B6E2B2F802A4062947763DC725DA509','1698BE55F0D4413E81436F6EF27E38D4','VARCHAR2(64)','PRIMARY KEY',NULL,1,0,0,'ADMIN',GETDATE(),NULL,NULL,NULL);
INSERT INTO CORE_DICTIONARYMX(RWID, ZDZ_DICTIONARYID, ZDZ_MINGC, ZDZ_BIANH, ZDZ_YANGS, ZDZ_SHIFQY, ZDZ_ZIDZ,SYS_SORT, SYS_CREATOR, SYS_CREATETIME, SYS_MODIFYBY, SYS_MODIFYTIME, SYS_STATUS)VALUES('D84D8B87D8644A1CA144790F3AB8F78C','1698BE55F0D4413E81436F6EF27E38D4','NVARCHAR2(32)',NULL,NULL,1,1,0,'ADMIN',GETDATE(),NULL,NULL,NULL);
INSERT INTO CORE_DICTIONARYMX(RWID, ZDZ_DICTIONARYID, ZDZ_MINGC, ZDZ_BIANH, ZDZ_YANGS, ZDZ_SHIFQY, ZDZ_ZIDZ,SYS_SORT, SYS_CREATOR, SYS_CREATETIME, SYS_MODIFYBY, SYS_MODIFYTIME, SYS_STATUS)VALUES('4B00C6B60F8448E7BE93D82A881828F9','1698BE55F0D4413E81436F6EF27E38D4','NVARCHAR2(50)',NULL,NULL,1,2,0,'ADMIN',GETDATE(),NULL,NULL,NULL);
INSERT INTO CORE_DICTIONARYMX(RWID, ZDZ_DICTIONARYID, ZDZ_MINGC, ZDZ_BIANH, ZDZ_YANGS, ZDZ_SHIFQY, ZDZ_ZIDZ,SYS_SORT, SYS_CREATOR, SYS_CREATETIME, SYS_MODIFYBY, SYS_MODIFYTIME, SYS_STATUS)VALUES('64844BB18FB24658A32098846149BFC6','1698BE55F0D4413E81436F6EF27E38D4','NVARCHAR2(100)',NULL,NULL,1,3,0,'ADMIN',GETDATE(),NULL,NULL,NULL);
INSERT INTO CORE_DICTIONARYMX(RWID, ZDZ_DICTIONARYID, ZDZ_MINGC, ZDZ_BIANH, ZDZ_YANGS, ZDZ_SHIFQY, ZDZ_ZIDZ,SYS_SORT, SYS_CREATOR, SYS_CREATETIME, SYS_MODIFYBY, SYS_MODIFYTIME, SYS_STATUS)VALUES('A06E55AF7F094881B0E5FCEFA6492448','1698BE55F0D4413E81436F6EF27E38D4','NVARCHAR2(255)',NULL,NULL,1,4,0,'ADMIN',GETDATE(),NULL,NULL,NULL);
INSERT INTO CORE_DICTIONARYMX(RWID, ZDZ_DICTIONARYID, ZDZ_MINGC, ZDZ_BIANH, ZDZ_YANGS, ZDZ_SHIFQY, ZDZ_ZIDZ,SYS_SORT, SYS_CREATOR, SYS_CREATETIME, SYS_MODIFYBY, SYS_MODIFYTIME, SYS_STATUS)VALUES('BFF00AF0119C4EB38A1A768E88C974B7','1698BE55F0D4413E81436F6EF27E38D4','NVARCHAR2(1000)',NULL,NULL,1,5,0,'ADMIN',GETDATE(),NULL,NULL,NULL);
INSERT INTO CORE_DICTIONARYMX(RWID, ZDZ_DICTIONARYID, ZDZ_MINGC, ZDZ_BIANH, ZDZ_YANGS, ZDZ_SHIFQY, ZDZ_ZIDZ,SYS_SORT, SYS_CREATOR, SYS_CREATETIME, SYS_MODIFYBY, SYS_MODIFYTIME, SYS_STATUS)VALUES('86041BF2B8E447C1863329840C0CC85D','1698BE55F0D4413E81436F6EF27E38D4','NVARCHAR2(2000)',NULL,NULL,1,6,0,'ADMIN',GETDATE(),NULL,NULL,NULL);
INSERT INTO CORE_DICTIONARYMX(RWID, ZDZ_DICTIONARYID, ZDZ_MINGC, ZDZ_BIANH, ZDZ_YANGS, ZDZ_SHIFQY, ZDZ_ZIDZ,SYS_SORT, SYS_CREATOR, SYS_CREATETIME, SYS_MODIFYBY, SYS_MODIFYTIME, SYS_STATUS)VALUES('F84B5C7E8FC4412C8C57DF5D02D28384','1698BE55F0D4413E81436F6EF27E38D4','NVARCHAR2(x)',NULL,NULL,1,7,0,'ADMIN',GETDATE(),NULL,NULL,NULL);
INSERT INTO CORE_DICTIONARYMX(RWID, ZDZ_DICTIONARYID, ZDZ_MINGC, ZDZ_BIANH, ZDZ_YANGS, ZDZ_SHIFQY, ZDZ_ZIDZ,SYS_SORT, SYS_CREATOR, SYS_CREATETIME, SYS_MODIFYBY, SYS_MODIFYTIME, SYS_STATUS)VALUES('AD60AD2C1EAB4F8A8648A068A154E23F','1698BE55F0D4413E81436F6EF27E38D4','INTEGER',NULL,NULL,1,8,0,'ADMIN',GETDATE(),NULL,NULL,NULL);
INSERT INTO CORE_DICTIONARYMX(RWID, ZDZ_DICTIONARYID, ZDZ_MINGC, ZDZ_BIANH, ZDZ_YANGS, ZDZ_SHIFQY, ZDZ_ZIDZ,SYS_SORT, SYS_CREATOR, SYS_CREATETIME, SYS_MODIFYBY, SYS_MODIFYTIME, SYS_STATUS)VALUES('F20F80956FE54C43B60B00EDBCB223C1','1698BE55F0D4413E81436F6EF27E38D4','NUMBER(15,2)',NULL,NULL,1,9,0,'ADMIN',GETDATE(),NULL,NULL,NULL);
INSERT INTO CORE_DICTIONARYMX(RWID, ZDZ_DICTIONARYID, ZDZ_MINGC, ZDZ_BIANH, ZDZ_YANGS, ZDZ_SHIFQY, ZDZ_ZIDZ,SYS_SORT, SYS_CREATOR, SYS_CREATETIME, SYS_MODIFYBY, SYS_MODIFYTIME, SYS_STATUS)VALUES('1CF8865566204D6E8A01DC7540F1A161','1698BE55F0D4413E81436F6EF27E38D4','NUMBER(15,x)',NULL,NULL,1,10,0,'ADMIN',GETDATE(),NULL,NULL,NULL);
INSERT INTO CORE_DICTIONARYMX(RWID, ZDZ_DICTIONARYID, ZDZ_MINGC, ZDZ_BIANH, ZDZ_YANGS, ZDZ_SHIFQY, ZDZ_ZIDZ,SYS_SORT, SYS_CREATOR, SYS_CREATETIME, SYS_MODIFYBY, SYS_MODIFYTIME, SYS_STATUS)VALUES('73EDEF5B15944594AA0626B8BD552C54','1698BE55F0D4413E81436F6EF27E38D4','DATE',NULL,NULL,1,11,0,'ADMIN',GETDATE(),NULL,NULL,NULL);
INSERT INTO CORE_DICTIONARYMX(RWID, ZDZ_DICTIONARYID, ZDZ_MINGC, ZDZ_BIANH, ZDZ_YANGS, ZDZ_SHIFQY, ZDZ_ZIDZ,SYS_SORT, SYS_CREATOR, SYS_CREATETIME, SYS_MODIFYBY, SYS_MODIFYTIME, SYS_STATUS)VALUES('1CB34FEC29FD40369050CBEE7FD1BFF2','1698BE55F0D4413E81436F6EF27E38D4','TIMESTAMP',NULL,NULL,1,12,0,'ADMIN',GETDATE(),NULL,NULL,NULL);

-- mysql DATATYPES
INSERT INTO CORE_DICTIONARY(RWID, ZDMX_BIANH, ZDMX_MINGC,  ZDMX_LEIX, ZDMX_GUANLBM, ZDMX_SUOSXT, SYS_SORT, SYS_CREATOR, SYS_CREATETIME, SYS_MODIFYBY, SYS_MODIFYTIME, SYS_STATUS)VALUES('653E3357D98B422DA2B3E4DE5D8C5162','CORE_MYSQL_DATATYPES','MYSQL表字段类型','0','','CORE',0,'ADMIN',GETDATE(),NULL,NULL,0);
INSERT INTO CORE_DICTIONARYMX(RWID, ZDZ_DICTIONARYID, ZDZ_MINGC, ZDZ_BIANH, ZDZ_YANGS, ZDZ_SHIFQY, ZDZ_ZIDZ,SYS_SORT, SYS_CREATOR, SYS_CREATETIME, SYS_MODIFYBY, SYS_MODIFYTIME, SYS_STATUS)VALUES('47DA7E60E5964F72B203AD68AF9189E7','653E3357D98B422DA2B3E4DE5D8C5162','VARCHAR(64)','PRIMARY KEY',NULL,1,0,0,'ADMIN',GETDATE(),NULL,NULL,NULL);
INSERT INTO CORE_DICTIONARYMX(RWID, ZDZ_DICTIONARYID, ZDZ_MINGC, ZDZ_BIANH, ZDZ_YANGS, ZDZ_SHIFQY, ZDZ_ZIDZ,SYS_SORT, SYS_CREATOR, SYS_CREATETIME, SYS_MODIFYBY, SYS_MODIFYTIME, SYS_STATUS)VALUES('5A0C79E1476F43E0BA1BE600ED07794A','653E3357D98B422DA2B3E4DE5D8C5162','NVARCHAR(32)',NULL,NULL,1,1,0,'ADMIN',GETDATE(),NULL,NULL,NULL);
INSERT INTO CORE_DICTIONARYMX(RWID, ZDZ_DICTIONARYID, ZDZ_MINGC, ZDZ_BIANH, ZDZ_YANGS, ZDZ_SHIFQY, ZDZ_ZIDZ,SYS_SORT, SYS_CREATOR, SYS_CREATETIME, SYS_MODIFYBY, SYS_MODIFYTIME, SYS_STATUS)VALUES('512120957AA54E15BFDABE868A3CE99C','653E3357D98B422DA2B3E4DE5D8C5162','NVARCHAR(50)',NULL,NULL,1,2,0,'ADMIN',GETDATE(),NULL,NULL,NULL);
INSERT INTO CORE_DICTIONARYMX(RWID, ZDZ_DICTIONARYID, ZDZ_MINGC, ZDZ_BIANH, ZDZ_YANGS, ZDZ_SHIFQY, ZDZ_ZIDZ,SYS_SORT, SYS_CREATOR, SYS_CREATETIME, SYS_MODIFYBY, SYS_MODIFYTIME, SYS_STATUS)VALUES('D98A0280E1E1442098FE41DFF8116E7D','653E3357D98B422DA2B3E4DE5D8C5162','NVARCHAR(100)',NULL,NULL,1,3,0,'ADMIN',GETDATE(),NULL,NULL,NULL);
INSERT INTO CORE_DICTIONARYMX(RWID, ZDZ_DICTIONARYID, ZDZ_MINGC, ZDZ_BIANH, ZDZ_YANGS, ZDZ_SHIFQY, ZDZ_ZIDZ,SYS_SORT, SYS_CREATOR, SYS_CREATETIME, SYS_MODIFYBY, SYS_MODIFYTIME, SYS_STATUS)VALUES('DBAD07E962B14D6ABF003DC05FCF972C','653E3357D98B422DA2B3E4DE5D8C5162','NVARCHAR(255)',NULL,NULL,1,4,0,'ADMIN',GETDATE(),NULL,NULL,NULL);
INSERT INTO CORE_DICTIONARYMX(RWID, ZDZ_DICTIONARYID, ZDZ_MINGC, ZDZ_BIANH, ZDZ_YANGS, ZDZ_SHIFQY, ZDZ_ZIDZ,SYS_SORT, SYS_CREATOR, SYS_CREATETIME, SYS_MODIFYBY, SYS_MODIFYTIME, SYS_STATUS)VALUES('AC667F1F01C44937A9AC2FBFA694AE3B','653E3357D98B422DA2B3E4DE5D8C5162','NVARCHAR(1000)',NULL,NULL,1,5,0,'ADMIN',GETDATE(),NULL,NULL,NULL);
INSERT INTO CORE_DICTIONARYMX(RWID, ZDZ_DICTIONARYID, ZDZ_MINGC, ZDZ_BIANH, ZDZ_YANGS, ZDZ_SHIFQY, ZDZ_ZIDZ,SYS_SORT, SYS_CREATOR, SYS_CREATETIME, SYS_MODIFYBY, SYS_MODIFYTIME, SYS_STATUS)VALUES('6DED675AB9524A0B8CA947B2A7CB7441','653E3357D98B422DA2B3E4DE5D8C5162','NVARCHAR(2000)',NULL,NULL,1,6,0,'ADMIN',GETDATE(),NULL,NULL,NULL);
INSERT INTO CORE_DICTIONARYMX(RWID, ZDZ_DICTIONARYID, ZDZ_MINGC, ZDZ_BIANH, ZDZ_YANGS, ZDZ_SHIFQY, ZDZ_ZIDZ,SYS_SORT, SYS_CREATOR, SYS_CREATETIME, SYS_MODIFYBY, SYS_MODIFYTIME, SYS_STATUS)VALUES('3BD3D2486101467497A13B3372660ADB','653E3357D98B422DA2B3E4DE5D8C5162','NVARCHAR(x)',NULL,NULL,1,7,0,'ADMIN',GETDATE(),NULL,NULL,NULL);
INSERT INTO CORE_DICTIONARYMX(RWID, ZDZ_DICTIONARYID, ZDZ_MINGC, ZDZ_BIANH, ZDZ_YANGS, ZDZ_SHIFQY, ZDZ_ZIDZ,SYS_SORT, SYS_CREATOR, SYS_CREATETIME, SYS_MODIFYBY, SYS_MODIFYTIME, SYS_STATUS)VALUES('7695FFBD5F774866BFC6561DBA2AC5B7','653E3357D98B422DA2B3E4DE5D8C5162','INT',NULL,NULL,1,8,0,'ADMIN',GETDATE(),NULL,NULL,NULL);
INSERT INTO CORE_DICTIONARYMX(RWID, ZDZ_DICTIONARYID, ZDZ_MINGC, ZDZ_BIANH, ZDZ_YANGS, ZDZ_SHIFQY, ZDZ_ZIDZ,SYS_SORT, SYS_CREATOR, SYS_CREATETIME, SYS_MODIFYBY, SYS_MODIFYTIME, SYS_STATUS)VALUES('7C4A27384DDB4311B11AA453D1226F95','653E3357D98B422DA2B3E4DE5D8C5162','DECIMAL(15,2)',NULL,NULL,1,9,0,'ADMIN',GETDATE(),NULL,NULL,NULL);
INSERT INTO CORE_DICTIONARYMX(RWID, ZDZ_DICTIONARYID, ZDZ_MINGC, ZDZ_BIANH, ZDZ_YANGS, ZDZ_SHIFQY, ZDZ_ZIDZ,SYS_SORT, SYS_CREATOR, SYS_CREATETIME, SYS_MODIFYBY, SYS_MODIFYTIME, SYS_STATUS)VALUES('AF7631750CB94339A026ADF3583381CB','653E3357D98B422DA2B3E4DE5D8C5162','DECIMAL(15,x)',NULL,NULL,1,10,0,'ADMIN',GETDATE(),NULL,NULL,NULL);
INSERT INTO CORE_DICTIONARYMX(RWID, ZDZ_DICTIONARYID, ZDZ_MINGC, ZDZ_BIANH, ZDZ_YANGS, ZDZ_SHIFQY, ZDZ_ZIDZ,SYS_SORT, SYS_CREATOR, SYS_CREATETIME, SYS_MODIFYBY, SYS_MODIFYTIME, SYS_STATUS)VALUES('BAB7BE71F8DE4157B1052F3ED19729AF','653E3357D98B422DA2B3E4DE5D8C5162','DATE',NULL,NULL,1,11,0,'ADMIN',GETDATE(),NULL,NULL,NULL);
INSERT INTO CORE_DICTIONARYMX(RWID, ZDZ_DICTIONARYID, ZDZ_MINGC, ZDZ_BIANH, ZDZ_YANGS, ZDZ_SHIFQY, ZDZ_ZIDZ,SYS_SORT, SYS_CREATOR, SYS_CREATETIME, SYS_MODIFYBY, SYS_MODIFYTIME, SYS_STATUS)VALUES('0F5E24AAF4B444D9873FD11FCC22D197','653E3357D98B422DA2B3E4DE5D8C5162','TIMESTAMP',NULL,NULL,1,12,0,'ADMIN',GETDATE(),NULL,NULL,NULL) ;

-- sqlserver DATATYPES
INSERT INTO CORE_DICTIONARY(RWID, ZDMX_BIANH, ZDMX_MINGC,  ZDMX_LEIX, ZDMX_GUANLBM, ZDMX_SUOSXT, SYS_SORT, SYS_CREATOR, SYS_CREATETIME, SYS_MODIFYBY, SYS_MODIFYTIME, SYS_STATUS)VALUES('53C9554987304A9A97B12AA47B253EC4','CORE_SQLSERVER_DATATYPES','SQLSERVER表字段类型','0','','CORE',0,'ADMIN',GETDATE(),NULL,NULL,0);
INSERT INTO CORE_DICTIONARYMX(RWID, ZDZ_DICTIONARYID, ZDZ_MINGC, ZDZ_BIANH, ZDZ_YANGS, ZDZ_SHIFQY, ZDZ_ZIDZ,SYS_SORT, SYS_CREATOR, SYS_CREATETIME, SYS_MODIFYBY, SYS_MODIFYTIME, SYS_STATUS)VALUES('AA1B6205969A44C0ADD6865094F95A62','53C9554987304A9A97B12AA47B253EC4','VARCHAR(64)','PRIMARY KEY',NULL,1,0,0,'ADMIN',GETDATE(),NULL,NULL,NULL);
INSERT INTO CORE_DICTIONARYMX(RWID, ZDZ_DICTIONARYID, ZDZ_MINGC, ZDZ_BIANH, ZDZ_YANGS, ZDZ_SHIFQY, ZDZ_ZIDZ,SYS_SORT, SYS_CREATOR, SYS_CREATETIME, SYS_MODIFYBY, SYS_MODIFYTIME, SYS_STATUS)VALUES('1B2463566EBA4FF9BB2DC2D9C22BB56E','53C9554987304A9A97B12AA47B253EC4','NVARCHAR(32)',NULL,NULL,1,1,0,'ADMIN',GETDATE(),NULL,NULL,NULL);
INSERT INTO CORE_DICTIONARYMX(RWID, ZDZ_DICTIONARYID, ZDZ_MINGC, ZDZ_BIANH, ZDZ_YANGS, ZDZ_SHIFQY, ZDZ_ZIDZ,SYS_SORT, SYS_CREATOR, SYS_CREATETIME, SYS_MODIFYBY, SYS_MODIFYTIME, SYS_STATUS)VALUES('C917B1A4DFD44F0D91B1A2917D87F090','53C9554987304A9A97B12AA47B253EC4','NVARCHAR(50)',NULL,NULL,1,2,0,'ADMIN',GETDATE(),NULL,NULL,NULL);
INSERT INTO CORE_DICTIONARYMX(RWID, ZDZ_DICTIONARYID, ZDZ_MINGC, ZDZ_BIANH, ZDZ_YANGS, ZDZ_SHIFQY, ZDZ_ZIDZ,SYS_SORT, SYS_CREATOR, SYS_CREATETIME, SYS_MODIFYBY, SYS_MODIFYTIME, SYS_STATUS)VALUES('409DA3C6436E4322A9490E24039A3641','53C9554987304A9A97B12AA47B253EC4','NVARCHAR(100)',NULL,NULL,1,3,0,'ADMIN',GETDATE(),NULL,NULL,NULL);
INSERT INTO CORE_DICTIONARYMX(RWID, ZDZ_DICTIONARYID, ZDZ_MINGC, ZDZ_BIANH, ZDZ_YANGS, ZDZ_SHIFQY, ZDZ_ZIDZ,SYS_SORT, SYS_CREATOR, SYS_CREATETIME, SYS_MODIFYBY, SYS_MODIFYTIME, SYS_STATUS)VALUES('F617BBADA5BA4271BB3F23BB5B50E4D7','53C9554987304A9A97B12AA47B253EC4','NVARCHAR(255)',NULL,NULL,1,4,0,'ADMIN',GETDATE(),NULL,NULL,NULL);
INSERT INTO CORE_DICTIONARYMX(RWID, ZDZ_DICTIONARYID, ZDZ_MINGC, ZDZ_BIANH, ZDZ_YANGS, ZDZ_SHIFQY, ZDZ_ZIDZ,SYS_SORT, SYS_CREATOR, SYS_CREATETIME, SYS_MODIFYBY, SYS_MODIFYTIME, SYS_STATUS)VALUES('B4960BB7E7C44770A828E643721D4DDB','53C9554987304A9A97B12AA47B253EC4','NVARCHAR(1000)',NULL,NULL,1,5,0,'ADMIN',GETDATE(),NULL,NULL,NULL);
INSERT INTO CORE_DICTIONARYMX(RWID, ZDZ_DICTIONARYID, ZDZ_MINGC, ZDZ_BIANH, ZDZ_YANGS, ZDZ_SHIFQY, ZDZ_ZIDZ,SYS_SORT, SYS_CREATOR, SYS_CREATETIME, SYS_MODIFYBY, SYS_MODIFYTIME, SYS_STATUS)VALUES('A0080859B6034E01A6B5AADF3ED7BB8E','53C9554987304A9A97B12AA47B253EC4','NVARCHAR(2000)',NULL,NULL,1,6,0,'ADMIN',GETDATE(),NULL,NULL,NULL);
INSERT INTO CORE_DICTIONARYMX(RWID, ZDZ_DICTIONARYID, ZDZ_MINGC, ZDZ_BIANH, ZDZ_YANGS, ZDZ_SHIFQY, ZDZ_ZIDZ,SYS_SORT, SYS_CREATOR, SYS_CREATETIME, SYS_MODIFYBY, SYS_MODIFYTIME, SYS_STATUS)VALUES('EF80349851A7414480E73FCB2F6CF3D9','53C9554987304A9A97B12AA47B253EC4','NVARCHAR(x)',NULL,NULL,1,7,0,'ADMIN',GETDATE(),NULL,NULL,NULL);
INSERT INTO CORE_DICTIONARYMX(RWID, ZDZ_DICTIONARYID, ZDZ_MINGC, ZDZ_BIANH, ZDZ_YANGS, ZDZ_SHIFQY, ZDZ_ZIDZ,SYS_SORT, SYS_CREATOR, SYS_CREATETIME, SYS_MODIFYBY, SYS_MODIFYTIME, SYS_STATUS)VALUES('E60F57FD738F456EA51EDAE5AB52F87D','53C9554987304A9A97B12AA47B253EC4','INT',NULL,NULL,1,8,0,'ADMIN',GETDATE(),NULL,NULL,NULL);
INSERT INTO CORE_DICTIONARYMX(RWID, ZDZ_DICTIONARYID, ZDZ_MINGC, ZDZ_BIANH, ZDZ_YANGS, ZDZ_SHIFQY, ZDZ_ZIDZ,SYS_SORT, SYS_CREATOR, SYS_CREATETIME, SYS_MODIFYBY, SYS_MODIFYTIME, SYS_STATUS)VALUES('CB157173D0D54B49BF0EDC58CDC1760D','53C9554987304A9A97B12AA47B253EC4','DECIMAL(15,2)',NULL,NULL,1,9,0,'ADMIN',GETDATE(),NULL,NULL,NULL);
INSERT INTO CORE_DICTIONARYMX(RWID, ZDZ_DICTIONARYID, ZDZ_MINGC, ZDZ_BIANH, ZDZ_YANGS, ZDZ_SHIFQY, ZDZ_ZIDZ,SYS_SORT, SYS_CREATOR, SYS_CREATETIME, SYS_MODIFYBY, SYS_MODIFYTIME, SYS_STATUS)VALUES('B34BBDDFF11B439D8C106D816B7E8284','53C9554987304A9A97B12AA47B253EC4','DECIMAL(15,x)',NULL,NULL,1,10,0,'ADMIN',GETDATE(),NULL,NULL,NULL);
INSERT INTO CORE_DICTIONARYMX(RWID, ZDZ_DICTIONARYID, ZDZ_MINGC, ZDZ_BIANH, ZDZ_YANGS, ZDZ_SHIFQY, ZDZ_ZIDZ,SYS_SORT, SYS_CREATOR, SYS_CREATETIME, SYS_MODIFYBY, SYS_MODIFYTIME, SYS_STATUS)VALUES('91C4422EBF214A66B12DDB469C1B06EB','53C9554987304A9A97B12AA47B253EC4','DATE',NULL,NULL,1,11,0,'ADMIN',GETDATE(),NULL,NULL,NULL);
INSERT INTO CORE_DICTIONARYMX(RWID, ZDZ_DICTIONARYID, ZDZ_MINGC, ZDZ_BIANH, ZDZ_YANGS, ZDZ_SHIFQY, ZDZ_ZIDZ,SYS_SORT, SYS_CREATOR, SYS_CREATETIME, SYS_MODIFYBY, SYS_MODIFYTIME, SYS_STATUS)VALUES('C71AB218FA964BDE90AC0C85CF4C15A2','53C9554987304A9A97B12AA47B253EC4','DATETIME',NULL,NULL,1,12,0,'ADMIN',GETDATE(),NULL,NULL,NULL);

-- Mybatis DATATYPES
INSERT INTO CORE_DICTIONARY(RWID, ZDMX_BIANH, ZDMX_MINGC,  ZDMX_LEIX, ZDMX_GUANLBM, ZDMX_SUOSXT, SYS_SORT, SYS_CREATOR, SYS_CREATETIME, SYS_MODIFYBY, SYS_MODIFYTIME, SYS_STATUS)VALUES('1E0C15F34AD2479986CCA57A3564E025','CORE_MYBATIS_DATATYPES','myBatis字段类型','0','','CORE',0,'ADMIN',GETDATE(),NULL,NULL,0);
INSERT INTO CORE_DICTIONARYMX(RWID, ZDZ_DICTIONARYID, ZDZ_MINGC, ZDZ_BIANH, ZDZ_YANGS, ZDZ_SHIFQY, ZDZ_ZIDZ,SYS_SORT, SYS_CREATOR, SYS_CREATETIME, SYS_MODIFYBY, SYS_MODIFYTIME, SYS_STATUS)VALUES('42E227693E944C0499F5239D4C1B1EA1','1E0C15F34AD2479986CCA57A3564E025','VARCHAR',NULL,NULL,1,0,0,'ADMIN',GETDATE(),NULL,NULL,NULL);
INSERT INTO CORE_DICTIONARYMX(RWID, ZDZ_DICTIONARYID, ZDZ_MINGC, ZDZ_BIANH, ZDZ_YANGS, ZDZ_SHIFQY, ZDZ_ZIDZ,SYS_SORT, SYS_CREATOR, SYS_CREATETIME, SYS_MODIFYBY, SYS_MODIFYTIME, SYS_STATUS)VALUES('CC9F271F58CB47EABDF0D2A6DCF8B1AB','1E0C15F34AD2479986CCA57A3564E025','VARCHAR',NULL,NULL,1,1,0,'ADMIN',GETDATE(),NULL,NULL,NULL);
INSERT INTO CORE_DICTIONARYMX(RWID, ZDZ_DICTIONARYID, ZDZ_MINGC, ZDZ_BIANH, ZDZ_YANGS, ZDZ_SHIFQY, ZDZ_ZIDZ,SYS_SORT, SYS_CREATOR, SYS_CREATETIME, SYS_MODIFYBY, SYS_MODIFYTIME, SYS_STATUS)VALUES('AA8C0138ACC24358BA015DE684D1A148','1E0C15F34AD2479986CCA57A3564E025','VARCHAR',NULL,NULL,1,2,0,'ADMIN',GETDATE(),NULL,NULL,NULL);
INSERT INTO CORE_DICTIONARYMX(RWID, ZDZ_DICTIONARYID, ZDZ_MINGC, ZDZ_BIANH, ZDZ_YANGS, ZDZ_SHIFQY, ZDZ_ZIDZ,SYS_SORT, SYS_CREATOR, SYS_CREATETIME, SYS_MODIFYBY, SYS_MODIFYTIME, SYS_STATUS)VALUES('2183F5ABD90A4F699AB7F52AF5C486C3','1E0C15F34AD2479986CCA57A3564E025','VARCHAR',NULL,NULL,1,3,0,'ADMIN',GETDATE(),NULL,NULL,NULL);
INSERT INTO CORE_DICTIONARYMX(RWID, ZDZ_DICTIONARYID, ZDZ_MINGC, ZDZ_BIANH, ZDZ_YANGS, ZDZ_SHIFQY, ZDZ_ZIDZ,SYS_SORT, SYS_CREATOR, SYS_CREATETIME, SYS_MODIFYBY, SYS_MODIFYTIME, SYS_STATUS)VALUES('C5E8AB14E71241CCB6589A3C735768A8','1E0C15F34AD2479986CCA57A3564E025','VARCHAR',NULL,NULL,1,4,0,'ADMIN',GETDATE(),NULL,NULL,NULL);
INSERT INTO CORE_DICTIONARYMX(RWID, ZDZ_DICTIONARYID, ZDZ_MINGC, ZDZ_BIANH, ZDZ_YANGS, ZDZ_SHIFQY, ZDZ_ZIDZ,SYS_SORT, SYS_CREATOR, SYS_CREATETIME, SYS_MODIFYBY, SYS_MODIFYTIME, SYS_STATUS)VALUES('89089D7BFEAE430DAC32EBBA540CEAD3','1E0C15F34AD2479986CCA57A3564E025','VARCHAR',NULL,NULL,1,5,0,'ADMIN',GETDATE(),NULL,NULL,NULL);
INSERT INTO CORE_DICTIONARYMX(RWID, ZDZ_DICTIONARYID, ZDZ_MINGC, ZDZ_BIANH, ZDZ_YANGS, ZDZ_SHIFQY, ZDZ_ZIDZ,SYS_SORT, SYS_CREATOR, SYS_CREATETIME, SYS_MODIFYBY, SYS_MODIFYTIME, SYS_STATUS)VALUES('9224E0AF459A49FE9F2FB7F326EE9949','1E0C15F34AD2479986CCA57A3564E025','VARCHAR',NULL,NULL,1,6,0,'ADMIN',GETDATE(),NULL,NULL,NULL);
INSERT INTO CORE_DICTIONARYMX(RWID, ZDZ_DICTIONARYID, ZDZ_MINGC, ZDZ_BIANH, ZDZ_YANGS, ZDZ_SHIFQY, ZDZ_ZIDZ,SYS_SORT, SYS_CREATOR, SYS_CREATETIME, SYS_MODIFYBY, SYS_MODIFYTIME, SYS_STATUS)VALUES('2BFA568A379A454786F99342B1711F0B','1E0C15F34AD2479986CCA57A3564E025','VARCHAR',NULL,NULL,1,7,0,'ADMIN',GETDATE(),NULL,NULL,NULL);
INSERT INTO CORE_DICTIONARYMX(RWID, ZDZ_DICTIONARYID, ZDZ_MINGC, ZDZ_BIANH, ZDZ_YANGS, ZDZ_SHIFQY, ZDZ_ZIDZ,SYS_SORT, SYS_CREATOR, SYS_CREATETIME, SYS_MODIFYBY, SYS_MODIFYTIME, SYS_STATUS)VALUES('51F15EFDA5344EC59759DB7B29D69CB7','1E0C15F34AD2479986CCA57A3564E025','INTEGER',NULL,NULL,1,8,0,'ADMIN',GETDATE(),NULL,NULL,NULL);
INSERT INTO CORE_DICTIONARYMX(RWID, ZDZ_DICTIONARYID, ZDZ_MINGC, ZDZ_BIANH, ZDZ_YANGS, ZDZ_SHIFQY, ZDZ_ZIDZ,SYS_SORT, SYS_CREATOR, SYS_CREATETIME, SYS_MODIFYBY, SYS_MODIFYTIME, SYS_STATUS)VALUES('8B1F6163C35A4CB9B6C79D23A65A1A3C','1E0C15F34AD2479986CCA57A3564E025','DECIMAL',NULL,NULL,1,9,0,'ADMIN',GETDATE(),NULL,NULL,NULL);
INSERT INTO CORE_DICTIONARYMX(RWID, ZDZ_DICTIONARYID, ZDZ_MINGC, ZDZ_BIANH, ZDZ_YANGS, ZDZ_SHIFQY, ZDZ_ZIDZ,SYS_SORT, SYS_CREATOR, SYS_CREATETIME, SYS_MODIFYBY, SYS_MODIFYTIME, SYS_STATUS)VALUES('90C7668E03E24D1694BCED6C161B0241','1E0C15F34AD2479986CCA57A3564E025','DECIMAL',NULL,NULL,1,10,0,'ADMIN',GETDATE(),NULL,NULL,NULL);
INSERT INTO CORE_DICTIONARYMX(RWID, ZDZ_DICTIONARYID, ZDZ_MINGC, ZDZ_BIANH, ZDZ_YANGS, ZDZ_SHIFQY, ZDZ_ZIDZ,SYS_SORT, SYS_CREATOR, SYS_CREATETIME, SYS_MODIFYBY, SYS_MODIFYTIME, SYS_STATUS)VALUES('BAAC4AFAE131455B833B586FA90DC86C','1E0C15F34AD2479986CCA57A3564E025','TIMESTAMP',NULL,NULL,1,11,0,'ADMIN',GETDATE(),NULL,NULL,NULL);
INSERT INTO CORE_DICTIONARYMX(RWID, ZDZ_DICTIONARYID, ZDZ_MINGC, ZDZ_BIANH, ZDZ_YANGS, ZDZ_SHIFQY, ZDZ_ZIDZ,SYS_SORT, SYS_CREATOR, SYS_CREATETIME, SYS_MODIFYBY, SYS_MODIFYTIME, SYS_STATUS)VALUES('67CE7BBB71714100835A6E8217F82C41','1E0C15F34AD2479986CCA57A3564E025','TIMESTAMP',NULL,NULL,1,12,0,'ADMIN',GETDATE(),NULL,NULL,NULL);

--默认添加的系统字段
INSERT INTO CORE_DICTIONARY(RWID, ZDMX_BIANH, ZDMX_MINGC,  ZDMX_LEIX, ZDMX_GUANLBM, ZDMX_SUOSXT, SYS_SORT, SYS_CREATOR, SYS_CREATETIME, SYS_MODIFYBY, SYS_MODIFYTIME, SYS_STATUS)VALUES('31832757E26947F08E77A6576CD3A601','CORE_DEFAULT_COLUMNS','默认添加的系统字段','2','','CORE',0,'ADMIN',GETDATE(),NULL,NULL,0);
INSERT INTO CORE_DICTIONARYMX(RWID, ZDZ_DICTIONARYID, ZDZ_MINGC, ZDZ_BIANH, ZDZ_YANGS, ZDZ_SHIFQY, ZDZ_ZIDZ,SYS_SORT, SYS_CREATOR, SYS_CREATETIME, SYS_MODIFYBY, SYS_MODIFYTIME, SYS_STATUS)VALUES('6CFD926710C2446687A6B7397A058232','31832757E26947F08E77A6576CD3A601','主键',NULL,NULL,1,'{"RWID":"","MXZD_TABLEID":"","MXZD_MINGC":"主键","MXZD_BIANH":"PRIMARY KEY","MXZD_YINGWM":"","MXZD_MIAOS":"","MXZD_ZIDLX":"0","MXZD_YUNXWK":0,"MXZD_SHIFWY":1,"MXZD_SHIFCJ":0,"MXZD_ZIDCD":"32","SYS_CREATETIME":"","SYS_CREATOR":"","SYS_MODIFYBY":"","SYS_MODIFYTIME":"","SYS_SORT":0,"SYS_STATUS":0}',0,'ADMIN',GETDATE(),NULL,NULL,NULL);
INSERT INTO CORE_DICTIONARYMX(RWID, ZDZ_DICTIONARYID, ZDZ_MINGC, ZDZ_BIANH, ZDZ_YANGS, ZDZ_SHIFQY, ZDZ_ZIDZ,SYS_SORT, SYS_CREATOR, SYS_CREATETIME, SYS_MODIFYBY, SYS_MODIFYTIME, SYS_STATUS)VALUES('F4D2B66C22FE416E9D09F881093BB35E','31832757E26947F08E77A6576CD3A601','创建人',NULL,NULL,1,'{"RWID":"","MXZD_TABLEID":"","MXZD_MINGC":"创建人","MXZD_BIANH":"SYS_CREATOR","MXZD_YINGWM":"","MXZD_MIAOS":"","MXZD_ZIDLX":"1","MXZD_YUNXWK":0,"MXZD_SHIFWY":0,"MXZD_SHIFCJ":0,"MXZD_ZIDCD":"32","SYS_CREATETIME":"","SYS_CREATOR":"","SYS_MODIFYBY":"","SYS_MODIFYTIME":"","SYS_SORT":0,"SYS_STATUS":0}',0,'ADMIN',GETDATE(),NULL,NULL,NULL);
INSERT INTO CORE_DICTIONARYMX(RWID, ZDZ_DICTIONARYID, ZDZ_MINGC, ZDZ_BIANH, ZDZ_YANGS, ZDZ_SHIFQY, ZDZ_ZIDZ,SYS_SORT, SYS_CREATOR, SYS_CREATETIME, SYS_MODIFYBY, SYS_MODIFYTIME, SYS_STATUS)VALUES('7F99AA6ADFF04BD1AF0B28AEFEA80D92','31832757E26947F08E77A6576CD3A601','创建时间',NULL,NULL,1,'{"RWID":"","MXZD_TABLEID":"","MXZD_MINGC":"创建时间","MXZD_BIANH":"SYS_CREATETIME","MXZD_YINGWM":"","MXZD_MIAOS":"","MXZD_ZIDLX":"11","MXZD_YUNXWK":0,"MXZD_SHIFWY":0,"MXZD_SHIFCJ":0,"MXZD_ZIDCD":"","SYS_CREATETIME":"","SYS_CREATOR":"","SYS_MODIFYBY":"","SYS_MODIFYTIME":"","SYS_SORT":0,"SYS_STATUS":0}',0,'ADMIN',GETDATE(),NULL,NULL,NULL);
INSERT INTO CORE_DICTIONARYMX(RWID, ZDZ_DICTIONARYID, ZDZ_MINGC, ZDZ_BIANH, ZDZ_YANGS, ZDZ_SHIFQY, ZDZ_ZIDZ,SYS_SORT, SYS_CREATOR, SYS_CREATETIME, SYS_MODIFYBY, SYS_MODIFYTIME, SYS_STATUS)VALUES('4ECD030E054B4C839111E9426AD72152','31832757E26947F08E77A6576CD3A601','修改人',NULL,NULL,1,'{"RWID":"","MXZD_TABLEID":"","MXZD_MINGC":"修改人","MXZD_BIANH":"SYS_MODIFYBY","MXZD_YINGWM":"","MXZD_MIAOS":"","MXZD_ZIDLX":"1","MXZD_YUNXWK":1,"MXZD_SHIFWY":0,"MXZD_SHIFCJ":0,"MXZD_ZIDCD":"32","SYS_CREATETIME":"","SYS_CREATOR":"","SYS_MODIFYBY":"","SYS_MODIFYTIME":"","SYS_SORT":0,"SYS_STATUS":0}',0,'ADMIN',GETDATE(),NULL,NULL,NULL);
INSERT INTO CORE_DICTIONARYMX(RWID, ZDZ_DICTIONARYID, ZDZ_MINGC, ZDZ_BIANH, ZDZ_YANGS, ZDZ_SHIFQY, ZDZ_ZIDZ,SYS_SORT, SYS_CREATOR, SYS_CREATETIME, SYS_MODIFYBY, SYS_MODIFYTIME, SYS_STATUS)VALUES('A4EB3793959C4D9AAB6314BCC3908720','31832757E26947F08E77A6576CD3A601','修改时间',NULL,NULL,1,'{"RWID":"","MXZD_TABLEID":"","MXZD_MINGC":"修改时间","MXZD_BIANH":"SYS_MODIFYTIME","MXZD_YINGWM":"","MXZD_MIAOS":"","MXZD_ZIDLX":"11","MXZD_YUNXWK":1,"MXZD_SHIFWY":0,"MXZD_SHIFCJ":0,"MXZD_ZIDCD":"","SYS_CREATETIME":"","SYS_CREATOR":"","SYS_MODIFYBY":"","SYS_MODIFYTIME":"","SYS_SORT":0,"SYS_STATUS":0}',0,'ADMIN',GETDATE(),NULL,NULL,NULL);
INSERT INTO CORE_DICTIONARYMX(RWID, ZDZ_DICTIONARYID, ZDZ_MINGC, ZDZ_BIANH, ZDZ_YANGS, ZDZ_SHIFQY, ZDZ_ZIDZ,SYS_SORT, SYS_CREATOR, SYS_CREATETIME, SYS_MODIFYBY, SYS_MODIFYTIME, SYS_STATUS)VALUES('56309F2EB3D5417E86B7D49D23F1C915','31832757E26947F08E77A6576CD3A601','流程实例ID',NULL,NULL,1,'{"RWID":"","MXZD_TABLEID":"","MXZD_MINGC":"流程实例ID","MXZD_BIANH":"SYS_PID","MXZD_YINGWM":"","MXZD_MIAOS":"","MXZD_ZIDLX":"1","MXZD_YUNXWK":1,"MXZD_SHIFWY":0,"MXZD_SHIFCJ":0,"MXZD_ZIDCD":32,"SYS_CREATETIME":"","SYS_CREATOR":"","SYS_MODIFYBY":"","SYS_MODIFYTIME":"","SYS_SORT":0,"SYS_STATUS":0}',0,'ADMIN',GETDATE(),NULL,NULL,NULL);
INSERT INTO CORE_DICTIONARYMX(RWID, ZDZ_DICTIONARYID, ZDZ_MINGC, ZDZ_BIANH, ZDZ_YANGS, ZDZ_SHIFQY, ZDZ_ZIDZ,SYS_SORT, SYS_CREATOR, SYS_CREATETIME, SYS_MODIFYBY, SYS_MODIFYTIME, SYS_STATUS)VALUES('A2BCD11559F34B1390E6169E26D82232','31832757E26947F08E77A6576CD3A601','审核状态',NULL,NULL,1,'{"RWID":"","MXZD_TABLEID":"","MXZD_MINGC":"审核状态","MXZD_BIANH":"SYS_AUDFLAG","MXZD_YINGWM":"","MXZD_MIAOS":"","MXZD_ZIDLX":"8","MXZD_YUNXWK":1,"MXZD_SHIFWY":0,"MXZD_SHIFCJ":0,"MXZD_ZIDCD":"","SYS_CREATETIME":"","SYS_CREATOR":"","SYS_MODIFYBY":"","SYS_MODIFYTIME":"","SYS_SORT":0,"SYS_STATUS":0}',0,'ADMIN',GETDATE(),NULL,NULL,NULL);
INSERT INTO CORE_DICTIONARYMX(RWID, ZDZ_DICTIONARYID, ZDZ_MINGC, ZDZ_BIANH, ZDZ_YANGS, ZDZ_SHIFQY, ZDZ_ZIDZ,SYS_SORT, SYS_CREATOR, SYS_CREATETIME, SYS_MODIFYBY, SYS_MODIFYTIME, SYS_STATUS)VALUES('A1E8E19BA29341018BBD282E6D254C84','31832757E26947F08E77A6576CD3A601','数据状态',NULL,NULL,1,'{"RWID":"","MXZD_TABLEID":"","MXZD_MINGC":"数据状态","MXZD_BIANH":"SYS_STATUS","MXZD_YINGWM":"","MXZD_MIAOS":"","MXZD_ZIDLX":"8","MXZD_YUNXWK":1,"MXZD_SHIFWY":0,"MXZD_SHIFCJ":0,"MXZD_ZIDCD":"","SYS_CREATETIME":"","SYS_CREATOR":"","SYS_MODIFYBY":"","SYS_MODIFYTIME":"","SYS_SORT":0,"SYS_STATUS":0}',0,'ADMIN',GETDATE(),NULL,NULL,NULL);
INSERT INTO CORE_DICTIONARYMX(RWID, ZDZ_DICTIONARYID, ZDZ_MINGC, ZDZ_BIANH, ZDZ_YANGS, ZDZ_SHIFQY, ZDZ_ZIDZ,SYS_SORT, SYS_CREATOR, SYS_CREATETIME, SYS_MODIFYBY, SYS_MODIFYTIME, SYS_STATUS)VALUES('A6B405B510644A5E8861034F85773032','31832757E26947F08E77A6576CD3A601','排序',NULL,NULL,1,'{"RWID":"","MXZD_TABLEID":"","MXZD_MINGC":"排序","MXZD_BIANH":"SYS_SORT","MXZD_YINGWM":"","MXZD_MIAOS":"","MXZD_ZIDLX":"8","MXZD_YUNXWK":1,"MXZD_SHIFWY":0,"MXZD_SHIFCJ":0,"MXZD_ZIDCD":"","SYS_CREATETIME":"","SYS_CREATOR":"","SYS_MODIFYBY":"","SYS_MODIFYTIME":"","SYS_SORT":0,"SYS_STATUS":0}',0,'ADMIN',GETDATE(),NULL,NULL,NULL);

-- 默认添加的树形系统字段
INSERT INTO CORE_DICTIONARY(RWID, ZDMX_BIANH, ZDMX_MINGC,  ZDMX_LEIX, ZDMX_GUANLBM, ZDMX_SUOSXT, SYS_SORT, SYS_CREATOR, SYS_CREATETIME, SYS_MODIFYBY, SYS_MODIFYTIME, SYS_STATUS)VALUES('12500D5C373A40409DBEDF24F04DF91A','CORE_DEFAULT_TREE_COLUMNS','默认添加的树形系统字段','2','','CORE',0,'ADMIN',GETDATE(),NULL,NULL,0);
INSERT INTO CORE_DICTIONARYMX(RWID, ZDZ_DICTIONARYID, ZDZ_MINGC, ZDZ_BIANH, ZDZ_YANGS, ZDZ_SHIFQY, ZDZ_ZIDZ,SYS_SORT, SYS_CREATOR, SYS_CREATETIME, SYS_MODIFYBY, SYS_MODIFYTIME, SYS_STATUS)VALUES('9809CE441BBE4AE5B3BBD3FCE6E34671','12500D5C373A40409DBEDF24F04DF91A','父节点ID',NULL,NULL,1,'{"RWID":"","MXZD_TABLEID":"","MXZD_MINGC":"父节点ID","MXZD_BIANH":"SYS_PARENTID","MXZD_MIAOS":"","MXZD_ZIDLX":"1","MXZD_SHIFCJ":0,"MXZD_SHIFWY":0,"MXZD_YINGWM":"","MXZD_YUNXWK":1,"MXZD_ZIDCD":"32","SYS_CREATETIME":"","SYS_CREATOR":"","SYS_MODIFYBY":"","SYS_MODIFYTIME":"","SYS_SORT":0,"SYS_STATUS":0}',0,'ADMIN',GETDATE(),NULL,NULL,NULL);
INSERT INTO CORE_DICTIONARYMX(RWID, ZDZ_DICTIONARYID, ZDZ_MINGC, ZDZ_BIANH, ZDZ_YANGS, ZDZ_SHIFQY, ZDZ_ZIDZ,SYS_SORT, SYS_CREATOR, SYS_CREATETIME, SYS_MODIFYBY, SYS_MODIFYTIME, SYS_STATUS)VALUES('50C25EB4BD75464AB204D160FCB3D6E8','12500D5C373A40409DBEDF24F04DF91A','所有父节点ID',NULL,NULL,1,'{"RWID":"","MXZD_TABLEID":"","MXZD_MINGC":"所有父节点ID","MXZD_BIANH":"SYS_PARENTS","MXZD_MIAOS":"","MXZD_ZIDLX":"4","MXZD_SHIFCJ":0,"MXZD_SHIFWY":0,"MXZD_YINGWM":"","MXZD_YUNXWK":1,"MXZD_ZIDCD":"0","SYS_CREATETIME":"","SYS_CREATOR":"","SYS_MODIFYBY":"","SYS_MODIFYTIME":"","SYS_SORT":0,"SYS_STATUS":0}',0,'ADMIN',GETDATE(),NULL,NULL,NULL);
INSERT INTO CORE_DICTIONARYMX(RWID, ZDZ_DICTIONARYID, ZDZ_MINGC, ZDZ_BIANH, ZDZ_YANGS, ZDZ_SHIFQY, ZDZ_ZIDZ,SYS_SORT, SYS_CREATOR, SYS_CREATETIME, SYS_MODIFYBY, SYS_MODIFYTIME, SYS_STATUS)VALUES('01899C3F83374F00ABD423DF1289C77F','12500D5C373A40409DBEDF24F04DF91A','是否叶子节点',NULL,NULL,1,'{"RWID":"","MXZD_TABLEID":"","MXZD_MINGC":"是否叶子节点","MXZD_BIANH":"SYS_ISLEAF","MXZD_MIAOS":"","MXZD_ZIDLX":"8","MXZD_SHIFCJ":0,"MXZD_SHIFWY":0,"MXZD_YINGWM":"","MXZD_YUNXWK":1,"MXZD_ZIDCD":"","SYS_CREATETIME":"","SYS_CREATOR":"","SYS_MODIFYBY":"","SYS_MODIFYTIME":"","SYS_SORT":0,"SYS_STATUS":0}',0,'ADMIN',GETDATE(),NULL,NULL,NULL);

-- 模型类型
INSERT INTO CORE_DICTIONARY(RWID, ZDMX_BIANH, ZDMX_MINGC,  ZDMX_LEIX, ZDMX_GUANLBM, ZDMX_SUOSXT, SYS_SORT, SYS_CREATOR, SYS_CREATETIME, SYS_MODIFYBY, SYS_MODIFYTIME, SYS_STATUS)VALUES('1589F6CBD7F94D5A85D206D18B1F41BE','CORE_MODEL_TYPE','表模型类型','0','','CORE',0,'ADMIN',GETDATE(),NULL,NULL,0);
INSERT INTO CORE_DICTIONARYMX(RWID, ZDZ_DICTIONARYID, ZDZ_MINGC, ZDZ_BIANH, ZDZ_YANGS, ZDZ_SHIFQY, ZDZ_ZIDZ,SYS_SORT, SYS_CREATOR, SYS_CREATETIME, SYS_MODIFYBY, SYS_MODIFYTIME, SYS_STATUS)VALUES('5FCED77876034F93B409AD8FD867AB97','1589F6CBD7F94D5A85D206D18B1F41BE','普通','Normal ',NULL,1,0,0,'ADMIN',GETDATE(),NULL,NULL,NULL);
INSERT INTO CORE_DICTIONARYMX(RWID, ZDZ_DICTIONARYID, ZDZ_MINGC, ZDZ_BIANH, ZDZ_YANGS, ZDZ_SHIFQY, ZDZ_ZIDZ,SYS_SORT, SYS_CREATOR, SYS_CREATETIME, SYS_MODIFYBY, SYS_MODIFYTIME, SYS_STATUS)VALUES('5A9C43EC75264414A224E3761EF7C4BB','1589F6CBD7F94D5A85D206D18B1F41BE','树形','Tree',NULL,1,1,1,'ADMIN',GETDATE(),NULL,NULL,NULL);
INSERT INTO CORE_DICTIONARYMX(RWID, ZDZ_DICTIONARYID, ZDZ_MINGC, ZDZ_BIANH, ZDZ_YANGS, ZDZ_SHIFQY, ZDZ_ZIDZ,SYS_SORT, SYS_CREATOR, SYS_CREATETIME, SYS_MODIFYBY, SYS_MODIFYTIME, SYS_STATUS)VALUES('7326322935E440E0BF184DEF0DCF9352','1589F6CBD7F94D5A85D206D18B1F41BE','目录','Catalog',NULL,1,2,2,'ADMIN',GETDATE(),NULL,NULL,NULL);

--字典类型 
INSERT INTO CORE_DICTIONARY(RWID, ZDMX_BIANH, ZDMX_MINGC,  ZDMX_LEIX, ZDMX_GUANLBM, ZDMX_SUOSXT, SYS_SORT, SYS_CREATOR, SYS_CREATETIME, SYS_MODIFYBY, SYS_MODIFYTIME, SYS_STATUS)VALUES('439BD47789C94934ACAF625B1F697DFC','CORE_DICTIONARY_TYPE','表模型类型','0','','CORE',0,'ADMIN',GETDATE(),NULL,NULL,0);
INSERT INTO CORE_DICTIONARYMX(RWID, ZDZ_DICTIONARYID, ZDZ_MINGC, ZDZ_BIANH, ZDZ_YANGS, ZDZ_SHIFQY, ZDZ_ZIDZ,SYS_SORT, SYS_CREATOR, SYS_CREATETIME, SYS_MODIFYBY, SYS_MODIFYTIME, SYS_STATUS)VALUES('7528A11B6AE84F92BCBC7F78511178B3','439BD47789C94934ACAF625B1F697DFC','通用值','List ',NULL,1,0,0,'ADMIN',GETDATE(),NULL,NULL,NULL);
INSERT INTO CORE_DICTIONARYMX(RWID, ZDZ_DICTIONARYID, ZDZ_MINGC, ZDZ_BIANH, ZDZ_YANGS, ZDZ_SHIFQY, ZDZ_ZIDZ,SYS_SORT, SYS_CREATOR, SYS_CREATETIME, SYS_MODIFYBY, SYS_MODIFYTIME, SYS_STATUS)VALUES('A3A1A5585D644148A16455E357C200E4','439BD47789C94934ACAF625B1F697DFC','关联表','Tree',NULL,1,1,1,'ADMIN',GETDATE(),NULL,NULL,NULL);
INSERT INTO CORE_DICTIONARYMX(RWID, ZDZ_DICTIONARYID, ZDZ_MINGC, ZDZ_BIANH, ZDZ_YANGS, ZDZ_SHIFQY, ZDZ_ZIDZ,SYS_SORT, SYS_CREATOR, SYS_CREATETIME, SYS_MODIFYBY, SYS_MODIFYTIME, SYS_STATUS)VALUES('05D8DD7CDC204D9CB1C0493B6BC694B2','439BD47789C94934ACAF625B1F697DFC','Json','Json',NULL,1,2,2,'ADMIN',GETDATE(),NULL,NULL,NULL);


--文件资源类型 
INSERT INTO CORE_DICTIONARY(RWID, ZDMX_BIANH, ZDMX_MINGC,  ZDMX_LEIX, ZDMX_GUANLBM, ZDMX_SUOSXT, SYS_SORT, SYS_CREATOR, SYS_CREATETIME, SYS_MODIFYBY, SYS_MODIFYTIME, SYS_STATUS)VALUES('655A947CBC424580BCDF5054D45AE8AD','CORE_FIELSRES_TYPE','文件资源类型','0','','CORE',0,'ADMIN',GETDATE(),NULL,NULL,0);
INSERT INTO CORE_DICTIONARYMX(RWID, ZDZ_DICTIONARYID, ZDZ_MINGC, ZDZ_BIANH, ZDZ_YANGS, ZDZ_SHIFQY, ZDZ_ZIDZ,SYS_SORT, SYS_CREATOR, SYS_CREATETIME, SYS_MODIFYBY, SYS_MODIFYTIME, SYS_STATUS)VALUES('22C40DDB9E1F4640BC7AB512D8B9DB2D','655A947CBC424580BCDF5054D45AE8AD','图标','ico',NULL,1,0,0,'ADMIN',GETDATE(),NULL,NULL,NULL);
INSERT INTO CORE_DICTIONARYMX(RWID, ZDZ_DICTIONARYID, ZDZ_MINGC, ZDZ_BIANH, ZDZ_YANGS, ZDZ_SHIFQY, ZDZ_ZIDZ,SYS_SORT, SYS_CREATOR, SYS_CREATETIME, SYS_MODIFYBY, SYS_MODIFYTIME, SYS_STATUS)VALUES('BA52F9C6651B4963AE5F01B34448CD33','655A947CBC424580BCDF5054D45AE8AD','图片','pic ',NULL,1,1,1,'ADMIN',GETDATE(),NULL,NULL,NULL);
INSERT INTO CORE_DICTIONARYMX(RWID, ZDZ_DICTIONARYID, ZDZ_MINGC, ZDZ_BIANH, ZDZ_YANGS, ZDZ_SHIFQY, ZDZ_ZIDZ,SYS_SORT, SYS_CREATOR, SYS_CREATETIME, SYS_MODIFYBY, SYS_MODIFYTIME, SYS_STATUS)VALUES('D2D60C6C26E545738164E11CCB029A34','655A947CBC424580BCDF5054D45AE8AD','文本','txt',NULL,1,2,2,'ADMIN',GETDATE(),NULL,NULL,NULL);
INSERT INTO CORE_DICTIONARYMX(RWID, ZDZ_DICTIONARYID, ZDZ_MINGC, ZDZ_BIANH, ZDZ_YANGS, ZDZ_SHIFQY, ZDZ_ZIDZ,SYS_SORT, SYS_CREATOR, SYS_CREATETIME, SYS_MODIFYBY, SYS_MODIFYTIME, SYS_STATUS)VALUES('48DDA43F5E9F4DC7B43A3BFAC8EE8A25','655A947CBC424580BCDF5054D45AE8AD','PDF','pdf',NULL,1,3,3,'ADMIN',GETDATE(),NULL,NULL,NULL);
INSERT INTO CORE_DICTIONARYMX(RWID, ZDZ_DICTIONARYID, ZDZ_MINGC, ZDZ_BIANH, ZDZ_YANGS, ZDZ_SHIFQY, ZDZ_ZIDZ,SYS_SORT, SYS_CREATOR, SYS_CREATETIME, SYS_MODIFYBY, SYS_MODIFYTIME, SYS_STATUS)VALUES('D1F542DBDC2A4A86952CB7D3AAEC5715','655A947CBC424580BCDF5054D45AE8AD','WORD','word',NULL,1,4,4,'ADMIN',GETDATE(),NULL,NULL,NULL);
INSERT INTO CORE_DICTIONARYMX(RWID, ZDZ_DICTIONARYID, ZDZ_MINGC, ZDZ_BIANH, ZDZ_YANGS, ZDZ_SHIFQY, ZDZ_ZIDZ,SYS_SORT, SYS_CREATOR, SYS_CREATETIME, SYS_MODIFYBY, SYS_MODIFYTIME, SYS_STATUS)VALUES('70E3CD588A7A4F8985BD428431980D4A','655A947CBC424580BCDF5054D45AE8AD','EXCEL','excel',NULL,1,5,5,'ADMIN',GETDATE(),NULL,NULL,NULL);
INSERT INTO CORE_DICTIONARYMX(RWID, ZDZ_DICTIONARYID, ZDZ_MINGC, ZDZ_BIANH, ZDZ_YANGS, ZDZ_SHIFQY, ZDZ_ZIDZ,SYS_SORT, SYS_CREATOR, SYS_CREATETIME, SYS_MODIFYBY, SYS_MODIFYTIME, SYS_STATUS)VALUES('8B970F14C6354B5FA5633F83A2DC8FFA','655A947CBC424580BCDF5054D45AE8AD','其他','other',NULL,1,6,5,'ADMIN',GETDATE(),NULL,NULL,NULL);

